/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the examples of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:BSD$
** You may use this file under the terms of the BSD license as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
**     the names of its contributors may be used to endorse or promote
**     products derived from this software without specific prior written
**     permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
** $QT_END_LICENSE$
**
****************************************************************************/

import Qt 4.7
import QtMultimediaKit 1.1
import QtQuick 1.1
import Qt.labs.components.native 1.0

Page {
    id: page
    property alias source : preview.source
    signal accepted(int offsetX, int offsetY, int cutWidth
                    , int previewWidth, double rota)

    Flickable {
        id : flick
        anchors.fill: boundary
        //        clip: true
        contentWidth: wrapper.width
        contentHeight: wrapper.height
        Rectangle {
            id: wrapper
            width: preview.width * preview.scale
            height: preview.height * preview.scale
            color: "#00ff0000"
            Image {
                id: preview
                anchors.centerIn: parent
                smooth: true
                scale : 1
            }
        }
        PinchArea  {
            property double minScale: Math.max(boundary.width*1.0/preview.width
                                               , boundary.height*1.0/preview.height)
            property Item target: preview
            property double tempScale : target.scale;
            property int startX : 0
            property int startY : 0
            property bool enableMove : false;
            function handleMove(state) {
                if (state === "Start") {
                    startX = pinch.center.x
                    startY = pinch.center.y
                    return ;
                } else if (state === "Update") {
                    target.x = pinch.center.x - startX;
                    target.y = pinch.center.y - startY;
                    return;
                }
            }

            //        property double startRotation: 0
            id: pinchArea
            anchors.fill: wrapper
            enabled: true
            onPinchStarted: {
                if (enableMove)handleMove("Start");
            }
            onPinchUpdated: {
                target.scale = tempScale * pinch.scale;
                if (enableMove)handleMove("Update")
            }
            onPinchFinished: {
                if (target.scale < minScale) target.scale = minScale;
                tempScale = target.scale;
            }
        }
    }

    Rectangle {
        property int borderWidth : 5
        id: boundary
        anchors.centerIn: parent;
        width: parent.width < parent.height ? parent.width : parent.height/* > 300 ? 300 : parent.width*/
        height: width
        border.width: borderWidth
        border.color: "#80ff0000"
        color: "#00000000"
    }

    tools: ToolBarLayout {
        ToolIcon {
            iconId: "toolbar-back"
            onClicked: {
                pageStack.pop()
            }
        }
        ToolButton {
            text: qsTr("Next")
            onClicked:  {
                var totoalScale = preview.scale
                accepted(flick.contentX / totoalScale
                         , flick.contentY / totoalScale
                         , (boundary.width - 2* boundary.borderWidth) / totoalScale
                         , preview.sourceSize.width
                         , flick.rotation)
                var checkinPage = pageStack.find(
                        function(p)
                        {
                            if (p.pageName === "CheckinPage")return true;
                            return false
                        });
                console.debug(checkinPage)
                pageStack.pop(checkinPage, true)
            }
        }
    }
}
