import QtQuick 1.0
import Qt.labs.components.native 1.0
import "./Network.js" as Network

// This component is used to show a combobox for selecting a city.
// This is used in several pages: 'register', 'change city' and 'add location'.

Column {

    id: root

    // The city id.
    property string city

    // Private properties
    property variant provinceObj
    property variant cityObj

    anchors {
        left: parent.left
        right: parent.right
    }

    ListModel {
        id: provinces
    }

    ListModel {
        id: cities
    }

    Button {
        anchors.left: parent.left
        anchors.right: parent.right
        text: (provinceObj)? provinceObj.name : ""

        onClicked: selectionDialog.open()

        SelectionDialog {
            id: selectionDialog
            titleText: qsTr("Select")
            selectedIndex: 0
            model: provinces
            onSelectedIndexChanged: {
                provinceObj = provinces.get(selectedIndex);
            }
        }
    }

    Button {
        anchors.left: parent.left
        anchors.right: parent.right
        text: (cityObj)? cityObj.name : ""
        opacity: (cityObj)? 1 : 0

        onClicked: citySelectionDialog.open()

        SelectionDialog {
            id: citySelectionDialog
            selectedIndex: 0
            model: cities
            onSelectedIndexChanged: {
                cityObj = cities.get(selectedIndex);
                city = cityObj.id;
            }
        }
    }

    onProvinceObjChanged: {
        cities.clear();
        if (provinceObj.cities === undefined) {
            cityObj = undefined;
            root.city = provinceObj.id;
            return;
        }
        cityObj = undefined;
        for (var i = 0; i < provinceObj.cities.count; i++) {
            var city = provinceObj.cities.get(i);
            cities.append(city);
            if (city.id === root.city) {
                cityObj = city;
            }
        }
        if (cityObj === undefined) {
            cityObj = provinceObj.cities.get(0);
            city = cityObj.id;
        }
    }

    Component.onCompleted: {
        var url = "/lbs/city_list.json";
        rootWindow.request(url, {}, undefined, undefined, function(ret, obj) {
            provinces.clear();
            for (var i = 0; i < obj.length; i++) {
                provinces.append(obj[i]);
            }
            if (!city)
                provinceObj = provinces.get(0);
            else {
                update();
            }
        });
    }

    onCityChanged: {
        update();
    }

    // Set the dialog city and province from a city id.
    // A little bit messy.
    function update() {
        for (var i = 0; i < provinces.count; i++) {
            var province = provinces.get(i);
            if (province.cities === undefined) {
                if (province.id === root.city) {
                    root.provinceObj = province;
                    root.cityObj = undefined;
                    return;
                }
                continue;
            }

            for (var j = 0; j < province.cities.count; j++) {
                var city = province.cities.get(j);
                if (city.id === root.city) {
                    root.provinceObj = province;
                    root.cityObj = city;
                    return;
                }
            }
        }
    }
}
