import QtQuick 1.0
import Qt.labs.components.native 1.0
import "." as Common
import "./Network.js" as Network


// Can be a badge or a surprise.  The behavior is almost the same, but the
// images are different.

Item {
    id: root
    property variant couponId
    property string name
    property variant image
    property string locationName
    property string description
    property bool usable
    property bool locked
    property bool used
    property bool isBadge
    property variant type

    signal redeemed()

    height: childrenRect.height
    width: parent.width

    Rectangle {
        color: "white"
        radius: 5
        width: parent.width
        height: childrenRect.height + 20

        Column {
            anchors {
                top: parent.top
                topMargin: 0
                left: parent.left
                leftMargin: 10
                right: parent.right
                rightMargin: 10
            }

            // XXX: The title is different for badges and surprises!
            Item {
                id: title
                height: titleBannerImage.height
                anchors {
                    left: parent.left
                    right: parent.right
                    margins: -10
                }

                Image {
                    id: titleBannerImage
                    anchors {
                        top: parent.top
                        topMargin: 0
                        left: parent.left
                        right: parent.right
                    }
                    source: (locked)? "qrc:///images/bg_surprise_badge_off.png" : "qrc:///images/bg_surprise_badge_on.png"
                }

                Text {
                    anchors {
                        left: parent.left
                        right: titleImage.left
                        verticalCenter: parent.verticalCenter
                        verticalCenterOffset: 8
                        margins: 10
                    }
                    text: name
                }
                Common.Image {
                    anchors {
                        right: parent.right
                        verticalCenter: parent.verticalCenter
                        verticalCenterOffset: 8
                        margins: 10
                    }
                    id: titleImage
                    source: image
                }
            }

            Text {
                text: qsTr("Welcome to %1").arg(locationName)
            }

            Text {
                width: parent.width
                wrapMode: Text.Wrap
                color: "grey"
                text: description
            }

            Item {
                width: parent.width
                height: redeemImage.height
                opacity: usable ? 1 : 0

                Image {
                    anchors.left: parent.left
                    id: redeemImage
                    source: (locked || used) ? "qrc:///images/ic_surprise_unavailable.png" : "qrc:///images/ic_surprise_available.png"
                }

                Text {
                    id: redeemText
                    anchors {
                        left: redeemImage.right
                        verticalCenter: parent.verticalCenter
                        margins: 10
                    }
                    text: {
                        if (locked)
                            return qsTr("Coupon Locked");
                        if (used)
                            return qsTr("Coupon Used");
                        qsTr("Use Coupon");
                    }
                }

                Common.Button {
                    opacity: (locked || used) ? 0 : 1
                    anchors {
                        right: parent.right
                        verticalCenter: parent.verticalCenter
                    }
                    text: qsTr("Redeem")

                    onClicked: {
                        var dialog = confirmRedeemDialog.createObject(rootWindow);
                        dialog.accepted.connect(function() {
                            var url = "/badges/usecoupon.json";
                            var args = {"id": root.couponId};
                            var onSuccess = function(ret, obj) {
                                redeemed();
                            };
                            rootWindow.request(url, args, undefined, undefined,
                                               onSuccess);
                        });
                        dialog.open();
                    }
                }
            }
        }
    }

    Component {
        id: confirmRedeemDialog
        QueryDialog {
            id: dialog
            titleText: qsTr("Redeem")
            message: qsTr("Redeem your surprise now? (Please confirm with your clerk)")
            acceptButtonText: qsTr("Redeem")
            rejectButtonText: qsTr("Cancel")
        }
    }
}
