import QtQuick 1.0

import "." as Common

Item {
    id: item
    height: childrenRect.height

    property variant postId
    property variant user
    property variant userId
    property variant location
    property variant locationId
    property variant userFollow
    property variant userFollowId
    property string type
    property variant body
    property variant photo
    property bool largePhoto: false
    property variant avatar
    property variant date
    property variant numLikes
    property variant isLike: false
    property variant commentCount
    property variant source

    property bool showUser: true
    property bool showLocation: true

    function update(numLikes, isLike, commentCount) {
        item.numLikes = numLikes
        item.isLike = isLike
        item.commentCount = commentCount
    }

    function getTitle(type, user, location, userFollow) {
        var ret;
        switch (type) {
        case "":
            return "";
            break;
        case "checkin":
            if (showUser && showLocation && user && location) {
                ret = qsTr('<a href="user">%1</a> at <a href="venue">%3</a>');
                return ret.arg(user).arg(location);
            } else if (showLocation && location) {
                return qsTr('<a href="venue">%1</a>').arg(location);
            } else if (showUser && user)
                return qsTr('<a href="user">%1</a>').arg(user);
            break;
        case "tip":
            if (showUser && showLocation && user && location) {
                ret = qsTr('<a href="user">%1</a> at <a href="venue">%2</a> tips :');
                return ret.arg(user).arg(location);
            }
            else if (showLocation && location)
                return qsTr('<a href="venue">%1</a> tips :').arg(location);
            else if (showUser && user)
                return qsTr('<a href="user">%1</a>').arg(user);
            break;
        case "shout":
            if (user)
                return qsTr('<a href="user">%1</a> said:').arg(user);
            break;
        case "photo":
            if (showUser && showLocation && user && location) {
                ret = qsTr('<a href="user">%1</a> at <a href="venue">%2</a> photo :');
                return ret.arg(user).arg(location);
            } else if (showLocation && location) {
                return qsTr('<a href="venue">%1</a>').arg(location);
            } else if (showUser && user) {
                return qsTr('<a href="user">%1</a>').arg(user);
            }

            break;
        case "comment":
            if (user)
                return qsTr('<a href="user">%1</a>').arg(user);
            break;
        case "schedule":
            if (user && location) {
                ret = qsTr('<a href="user">%1</a> plan to visit <a href="venue">%2</a>');
                return ret.arg(user).arg(location);
            }
            break;
        case "follow":
            if (user && userFollow) {
                ret = qsTr('<a href="user">%1</a> followed <a href="follow">%2</a>');
                return ret.arg(user).arg(userFollow);
            }
            break;
        case "venue_follow":
            if (user && location) {
                ret = qsTr('<a href="user">%1</a> followed <a href="venue_follow">%2</a>');
                return ret.arg(user).arg(location);
            }
            break;
        default:
            return "";
            break;
        }
    }

    Common.Image {
        id: avatarImage
        source: avatar
        defaultSource: "qrc:///images/img_nopic_thumb.png"
        background: "qrc:///images/bg_avatar.png"
        imageHeight: 45
        imageWidth: 45
        anchors {
            left: parent.left
            top: parent.top
        }
    }

    Column {
        id: title
        anchors {
            left: avatarImage.right
            right: parent.right
            top: parent.top
            leftMargin: avatar !== undefined ? 10 : 0
        }

        Text {
            id: titleText
            font.pixelSize: rootWindow.style.fontNormalSize

            text: "<style type='text/css'>a:link {text-decoration: none}</style>" + getTitle(type, user, location, userFollow)
            onLinkActivated: {
                // For the moment we support 2 types of links: "user" and "venue".
                // "follow" and "user_follow" are used in the texts but we can never
                // click on them so they are not included here.
                if (link === "user") {
                    rootWindow.pushPage(Qt.resolvedUrl("../Pages/UserProfilePage.qml"),
                                        {"userId": userId,
                                         "userNick": user});
                } else if (link === "venue") {
                    rootWindow.pushPage(Qt.resolvedUrl("../Pages/LocationPage.qml"),
                                        {"name": location,
                                         "guid": locationId});
                } else {
                    console.log("ERROR: unknow link:", link);
                }
            }
        }

        Text {
            id: titleBodyText
            font.pixelSize: rootWindow.style.fontNormalSize
            text: (body)? body : ""
            wrapMode: Text.Wrap
            color: "black"
            width:  parent.width
            opacity: (body)? 1 : 0
        }
    }

    Common.Image {
        id: image
        anchors {
            left: (largePhoto)? parent.left : title.left
            top: (title.height < avatarImage.height && largePhoto) ? avatarImage.bottom : title.bottom
            topMargin: (photo)? 10 : 0
        }

        imageWidth: (photo)? ((largePhoto)? 300 : 120) : 0
        imageHeight: (photo)? ((largePhoto)? 300 : 120) : 0
        source: {
            if (photo === undefined)
                return undefined;
            if (largePhoto)
                return "%1&size=300".arg(photo);
            else
                return photo;
        }
        defaultSource: (largePhoto)? "qrc:///images/loading300.png": "qrc:///images/img_nopic.png"
        opacity: (photo !== undefined)? 1 : 0
    }

    Date {
        anchors {
            left: image.left
            top: image.bottom
            topMargin: (photo)? 10 : 5
        }

        opacity: item.date ? 1 : 0
        font.pixelSize: rootWindow.style.fontSmallSize
        color: "grey"
        date: item.date ? item.date : new Date()
    }

    Row {
        id: counts
        height: childrenRect.height
        anchors {
            right: parent.right
            top: image.bottom
            topMargin: (photo)? 10 : 5
        }
        spacing: 7

        Row {
            id: likes
            opacity: (numLikes === undefined)? 0 : 1
            Image {
                source: (isLike)? "qrc:///images/like_me.png" : "qrc:///images/like_no_me.png"
                anchors.verticalCenter: parent.verticalCenter
                width: sourceSize.width * rootWindow.style.scale
                height: sourceSize.height * rootWindow.style.scale
            }
            spacing: 5
            Text {
                font.pixelSize: rootWindow.style.fontSmallSize
                color: "grey"
                text: qsTr("(%1)").arg(numLikes)
            }

        }
        Row {
            opacity: (commentCount === undefined)? 0 : 1
            Image {
                source: "qrc:///images/img_reply.png"
                anchors.verticalCenter: parent.verticalCenter
                width: sourceSize.width * rootWindow.style.scale
                height: sourceSize.height * rootWindow.style.scale
            }
            spacing: 5
            Text {
                font.pixelSize: rootWindow.style.fontSmallSize
                color: "grey"
                text: qsTr("(%1)").arg(commentCount)
            }
        }
    }

    Column {
        anchors {
            right: parent.right
            top: image.bottom
            topMargin: (photo)? 10 : 5
        }

        Text {
            font.pixelSize: rootWindow.style.fontSmallSize
            text: (source)? source : ""
            color: "grey"
            opacity: (source)? 1 : 0
        }
    }

    // Show the item in a new page.
    function show() {
        if (type === 'follow') {
            rootWindow.pushPage(Qt.resolvedUrl("../Pages/UserProfilePage.qml"),
                                {"userId": userFollowId,
                                 "userNick": userFollow})
            return
        }
        if (model.type_name == 'venue_follow') {
            rootWindow.pushPage(Qt.resolvedUrl("../Pages/LocationPage.qml"),
                                {"name": location,
                                 "guid": locationId})
            return
        }

        var page = rootWindow.pushPage(Qt.resolvedUrl("../Pages/FeedDetailPage.qml"),
                  {"postId": postId,
                   "userId": userId,
                   "type": type,
                   "user": user,
                   "userFollow": userFollow,
                   "body": body,
                   "location": location,
                   "locationId": locationId,
                   "numLikes": numLikes,
                   "isLike": isLike,
                   "commentCount": commentCount,
                   "date": date,
                   "photo": photo,
                   "source": source});
        page.updated.connect(item.update);
    }
}
