import QtQuick 1.0

// Generic component that can be used as the parent of the list items.
// This will automatically add a highlited color when the item is pressed,
// as well as a border and a separation line between the items.
//
// Note: For the moment the child element needs to be specified as the
// `content` property of the item.
// TODO: make content the default property so that we don't need this hack.
Rectangle {

    property bool allowClick: false
    signal clicked
    signal pressAndHold
    property Component content
    property alias item: loader.item

    id: listItem
    width: ListView.view.width
    height: loader.height + 20
    color: "#ebebeb"

    Rectangle {
        id: highlight
        color: "#959595"
        anchors.fill: parent
        opacity: 0
    }

    Rectangle {
        height: 2
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        gradient: Gradient {
            GradientStop { position: 0.0; color: "#b7b7b7" }
            GradientStop { position: 1.0; color: "#ffffff" }
        }
    }

    MouseArea {
        z: (allowClick)? 0 : 1
        anchors.fill: parent
        onPressed: {
            internal.state = "Pressed"
            highlight.opacity = 1
        }
        onReleased: {
            internal.state = ""
            releasedEffect.restart()
        }

        onCanceled: {
            internal.state = ""
            releasedEffect.restart()
        }

        onClicked: {
            parent.clicked()
        }

        onPressAndHold: {
            parent.pressAndHold()
        }
    }

    Loader {
        id: loader
        x: 10
        y: 10
        height: item.height
        width: listItem.width - 20
        sourceComponent: content
    }

    StateGroup {
        id: internal
        states: [
            State { name: "Pressed" },
            State { name: "" }
        ]
    }

    SequentialAnimation {
        id: releasedEffect
        PropertyAnimation {
            target: highlight
            property: "opacity"
            to: 0
            easing.type: Easing.Linear
            duration: 150
        }
    }
}
