import QtQuick 1.0

import Qt.labs.components.native 1.0

import "." as Common
import "Utils.js" as Utils

// Specialized list item to show a menu.
// This is used for example in the user profile page.
Common.ListItem {
    id: listItem
    property string text
    property variant icon
    property variant nb
    // This can be set to a list of thumbs url.
    property variant images: []
    property variant date
    property variant avatar

    // The parent Item is just there to add some border
    content: Item {
        height: 50
        anchors {
            left: parent.left
            right: parent.right
        }

        Common.Image {
            id: image
            anchors {
                left: parent.left
                verticalCenter: parent.verticalCenter
            }
            source: icon
        }

        Text {
            id: text
            font.pixelSize: rootWindow.style.fontNormalSize
            anchors {
                left: image.right
                leftMargin: icon ? 10 : 0
                right: rightText.left
                rightMargin: 10
                verticalCenter: parent.verticalCenter
            }
            text: listItem.text
            elide: Text.ElideRight
        }

        Row {
            id: images
            anchors {
                left: image.right
                verticalCenter: parent.verticalCenter
                margins: 10
            }
            spacing: 10
            Repeater {
                model: listItem.images
                delegate: Common.Image {
                    source: modelData
                    defaultSource: "qrc:///images/img_nopic_thumb.png"
                }
            }
        }

        Item {
            id: rightText
            width: Math.max(children[0].width, children[1].width)
            height: parent.height
            anchors {
                right: parent.right
                verticalCenter: parent.verticalCenter
            }

            // XXX: I don't like that.  We should use only a single text
            //      item.
            Text {
                anchors {
                    right: parent.right
                    verticalCenter: parent.verticalCenter
                }
                font.pixelSize: rootWindow.style.fontNormalSize
                color: "black"
                text: (listItem.nb !== undefined)? listItem.nb : ""
                opacity: text ? 1 : 0
            }

            Date {
                anchors {
                    right: parent.right
                    verticalCenter: parent.verticalCenter
                }
                opacity: (listItem.date !== undefined) ? 1 : 0
                date: listItem.date ? listItem.date : new Date()
                font.pixelSize: rootWindow.style.fontNormalSize
                color: "black"
            }
        }

        Common.Image {
            anchors {
                right: parent.right
                verticalCenter: parent.verticalCenter
            }
            source: avatar
        }
    }
}
