.pragma library

// Global variable containing jiepang server address
var server = "http://api.jiepang.com"

var credentials = undefined
function setCredentials(login, password) {
    credentials = Qt.btoa(login + ":" + password)
}

// Global variable containing the source parameter of the server calls
var source = undefined
function setSource(value) {
    source = value;
}

// json parsing reveiver used to Parse date values of the type: "2011-07-19 13:24:15"
// into javascript date.
function jsonReviver(key, value) {
    if (key === 'created_on' || key === 'user_last_checkin_time' || key === 'p_created_on') {
        var a = /^(\d{4})-(\d{2})-(\d{2}) (\d{2}):(\d{2}):(\d{2})$/.exec(value);
        if (a) {
            return new Date(Date.UTC(+a[1], +a[2] - 1, +a[3], +a[4], +a[5], +a[6]));
        }
    }
    return value
}

function handleRequestState(request, callback) {
    // There is a bug in qml XMLHttpRequest implementation: when the server
    // returns a http 500 response (server error), the request object
    // will have the status set to 0 when the readyState is DONE.
    // To bypass this bug we notice that the responseText is already set
    // when we are in the LOADING state.
    // TODO: try to remove this when qt version is higher than 4.7.3.
    if (request.readyState === XMLHttpRequest.LOADING) {
        if (request.status !== 200 && request.status !== 0 && request.responseText) {
            console.log("Warning: getting XMLHttpRequest result before request complete.");
            var eobj = undefined;
            if (request.responseText)
                eobj = JSON.parse(request.responseText, jsonReviver);
            callback(request.status, eobj);
            // We use this attribute to flag the request as already done.
            request.done = true;
        }
    }

    if (request.readyState === XMLHttpRequest.DONE) {
        if (request.done)
            return;
        if (request.status !== 200) { // Got an error
            console.log("Error request", request.status);
        }
        var obj = undefined;
        if (request.responseText)
            obj = JSON.parse(request.responseText, jsonReviver);
        callback(request.status, obj);
    }
}

function doPost(url, params, callback, addDefaultParams) {
    // Add jiepang server address if no server is specified:
    url = resolveUrl(url);
    var paramsString = parseParam(params);
    if (addDefaultParams !== false && source) {
        paramsString += "&source=%1".arg(source);
    }
    var request = new XMLHttpRequest;
    request.done = false; // Hack. See handleRequestState().
    request.open("Post", url);
    request.setRequestHeader("Content-Type","application/x-www-form-urlencoded;");
    if (credentials !== undefined)
        request.setRequestHeader("Authorization", "Basic " + credentials);
    request.onreadystatechange = function() {
        handleRequestState(request, callback)
    }
    console.debug("Send request", url, paramsString)
    request.send(paramsString);
}

function doGet(url, params, callback) {
    var paramsString = parseParam(params)
    var request = new XMLHttpRequest;
    request.done = false; // Hack. See handleRequestState().
    request.open("Get", url + "?" + paramsString);
    request.setRequestHeader("Content-Type","application/x-www-form-urlencoded;");
    if (credentials !== undefined)
        request.setRequestHeader("Authorization", "Basic " + credentials);
    request.onreadystatechange = function() {
        handleRequestState(request, callback)
    }
    console.debug("Send request", url, paramsString)
    request.send()
}

function resolveUrl(url) {
    url = "" + url; // Turn url into a string.
    if (url.indexOf("http://") !== 0)
        url = server + url;
    return url;
}

function parseParam(params) {
    var paramsStrings = []
    for (var i in params) {
        var param = params[i];
        if (param === undefined)
            console.log("Warning: undefined parameter:", i);
        if (typeof(param) === "object") {
            param = JSON.stringify(param);
        }
        paramsStrings.push(i + "=" + param);
    }
    return paramsStrings.join("&")
}
