import QtQuick 1.0
import Qt.labs.components.native 1.0 as Symbian
import "../Common" as Common

// Our own cutom Page component.
// This is almost the same the symbian page, but with a default white
// background and a menu with a back button
Symbian.Page {
    id: page
    property bool scrollable: false
    property color background : "#ebebeb";
    property alias header: p_header
    property alias headerButtons: p_header.children
    property alias title: p_header.title
    default property alias content: f_content.data

    anchors.fill: parent
    anchors.topMargin: p_header.height

    // background rectangle it should be placed herer or it may cover other item
    Rectangle {
        anchors.fill: parent;
        id: backgroundRect
        color: background;
    }

    Common.PageHeader {
        id: p_header
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
            topMargin: -p_header.height
        }
    }

    Flickable {
        id: p_flickable
        anchors.fill: parent
        contentWidth: width
        contentHeight: scrollable ? f_content.height : height
        interactive: contentHeight > height
        clip: true
        Item {
            id: f_content
            height: scrollable ? childrenRect.height : parent.height
            width: parent.width
        }
    }

    tools: Symbian.ToolBarLayout {
        Symbian.ToolIcon {
            iconId: "icon-m-toolbar-back"
            onClicked: {
                pageStack.pop()
            }
        }
    }

    // The default refresh method will try to refresh all the list presents
    // in the page.  The page can reimplements this function to do specific
    // action on refresh.
    function refresh() {
        refreshLists(page);
    }

    function refreshLists(item) {
        if (item.type !== undefined && item.type === 'List') {
            item.refresh();
            return
        }
        for (var i = 0; i < item.children.length; i++) {
            refreshLists(item.children[i]);
        }
    }
}
