import QtQuick 1.0
// XXX: I comment this because it doesn't work with qt-mobility 1.2.
// But we should revert it back once it does.
// import QtMobility.systeminfo 1.1

// Instead we get the network info from C++.
import JiePang 1.0 as JiePang

import QtMobility.location 1.1

// TODO: In case of an error, if we had previously found a location, show
// a message that ask the user if it is ok to use the last location and if
// so use it.
Item {

    property variant longitude
    property variant latitude
    // Set to true if we cannot determine location doe to an error.
    property bool error: false

    // Private properties
    property bool busy: false

    JiePang.NetworkInfo {
        id: networkInfo
    }

    PositionSource {
         id: positionSource
         active: false

         onPositionChanged: {
//             console.log("Got position", position,  position.coordinate);
             longitude = position.coordinate.longitude;
             latitude = position.coordinate.latitude;
             error = false;
         }
    }

    // Update the position if an update is not already pending.
    function refresh() {
        if (busy)
            return;
        longitude = undefined;
        latitude = undefined;
        callGoogleGear();
    }

    // Make a call the google gear geolocaliation services to get the
    // position from mobile network.
    function callGoogleGear() {
        if (!networkInfo.cellId) {
            console.log("Apparently not connected to a network cell tower");
            error = true;
            positionSource.update();
            return;
        }

        error = false;
        busy = true;
        // var url = "http://www.google.com/loc/json";
        var url = "http://googleloc.jiepang.com/loc/json";

        var obj = {
            "version": "1.1.0",
            "host": "maps.google.com",
            "cell_towers": [{
                "cell_id": "" + networkInfo.cellId,
                "location_area_code": networkInfo.locationAreaCode,
                "mobile_country_code": networkInfo.currentMobileCountryCode,
                "mobile_network_code": networkInfo.currentMobileNetworkCode
            }]
        };
        var json = JSON.stringify(obj);

        var request = new XMLHttpRequest;
        request.open("Post", url);
        request.onreadystatechange = function() {
            if (request.readyState == XMLHttpRequest.DONE) {
                console.log("got reply from", url);
                busy = false;
                if (request.status != 200) {
                    console.log("Error request", request.status);
                    error = true;
                } else {
                    try {
                        var result = JSON.parse(request.responseText);
                        longitude = result.location.longitude;
                        latitude = result.location.latitude;
                    } catch (err) {
                        console.log("Error", err);
                        error = true;
                    }
                }
                // Update the GPS position
                positionSource.update();
            }
        }
        console.log("sending request to", url, json);
        request.send(json);
    }
}
