import QtQuick 1.0
import Qt.labs.components.native 1.0

import "../Common" as Common
import "../Common/Network.js" as Network

Common.Page {
    id: page

    property variant query

    Item {
        id: searchBar
        height: childrenRect.height
        anchors {
            top: parent.top
            left: parent.left
            right: parent.right
            margins: 10
        }

        TextField {
            id: textField
            placeholderText: qsTr("Search friends")
            anchors {
                left: parent.left
                right: searchButton.left
                rightMargin: 10
            }
        }

        Common.Button {
            id: searchButton
            text: qsTr("Search")
            anchors {
                right: parent.right
            }

            onClicked: {
                page.query = textField.text
            }
        }
    }

    Common.List {
        anchors {
            left: parent.left
            right: parent.right
            top: searchBar.bottom
            bottom: parent.bottom
            topMargin: 10
            bottomMargin: 10
        }

        requestUrl: "/users/search.json"
        requestParams: {"q": page.query}
        usePages: false
        canGetMore: false
        countParam: ""

        // Simple friend item
        // XXX: we should put it into a generic component.
        delegate: Common.ListItem {
            id: listItem
            content: Row {
                spacing: 10
                Common.Image {
                    source: model.avatar_thumb
                    defaultSource: "qrc:///images/img_nopic_thumb.png"
                }
                Text {
                    anchors.verticalCenter: parent.verticalCenter
                    color: "black"
                    text: model.nick
                    font.pixelSize: rootWindow.style.fontNormalSize
                }
            }

            onClicked: {
                rootWindow.pushPage(Qt.resolvedUrl("UserProfilePage.qml"),
                                    {"userId": model.id,
                                     "avatar": model.avatar_small,
                                     "userNick": model.nick});
            }
        }

        function parseResult(result, model) {
            for (var i = 0; i < result.length; i++) {
                var obj = result[i];
                model.append(obj)
            }
        }
    }

}
