import QtQuick 1.0
import Qt.labs.components.native 1.0
import "../Common" as Common

// XXX: fix this dialog
CommonDialog {

    id: dialog
    property alias city: cityPicker.city
    property alias name: locationText.text
    property alias address: addressText.text

    titleText: qsTr("Add Location")

    height: 600

    content: Item {
        anchors.fill: parent
        Common.CityPicker {
            id: cityPicker
            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
            }
        }

        TextField {
            id: locationText
            anchors {
                left: parent.left
                right: parent.right
                top: cityPicker.bottom
                margins: 10
            }
            placeholderText: qsTr("Location")
        }

        TextArea {
            id: addressText
            anchors {
                left: parent.left
                right: parent.right
                top: locationText.bottom
                bottom: buttons.top
                margins: 10
            }

            placeholderText: qsTr("Address")
        }

        Row {
            id: buttons
            anchors {
                left: parent.left
                right: parent.right
                bottom: parent.bottom
                margins: 10
            }

            height: childrenRect.height
            spacing: 10

            ToolButton {
                text: qsTr("Add Location")
                onClicked: {
                    if (!name || !address) {
                        rootWindow.showDialog(qsTr("Cannot add location"),
                                              qsTr("Location and address are required"));
                        return;
                    }
                    var url = "/locations/add.json"
                    var geom = {type: "Point",
                                coordinates: [
                                    rootWindow.positionManager.longitude,
                                    rootWindow.positionManager.latitude]};
                    var args = {city: rootWindow.user.city,
                                name: dialog.name,
                                addr: dialog.address,
                                geom: geom};
                    var onResult = function(ret, obj) {
                        dialog.accept();
                        var location = obj.location;
                        rootWindow.pushPage(Qt.resolvedUrl("LocationPage.qml"),
                                            {"name": location.meta.name,
                                            "addr": location.meta.addr,
                                            "guid": location.guid,
                                            "longitude": location.long,
                                            "latitude": location.lat });
                    }
                    rootWindow.request(url, args,
                                       undefined, qsTr("Cannot create location"),
                                       onResult);
                }
            }

            ToolButton {
                text: qsTr("Cancel")
                onClicked: {
                    dialog.reject()
                }
            }
        }
    }
}
