import QtQuick 1.0
import Qt.labs.components.native 1.0

import "../Common" as Common


QueryDialog {

    property string name
    property string badgeId
    property string description
    property url img
    property bool usable: false
    property int couponNum

    signal couponUsed(int numCoupon);

    // private properties

    property bool justUsed: false
    // Set to true to show the use confirmation buttons.
    property bool confirmMode: false
    property bool showUseButton: confirmMode === false && usable && couponNum > 0 && !justUsed

    id: root
    titleText: name

    content:  Flickable {
        id: flickable
        property int upperBound: root.parent.height - 400
        height: Math.min(column.height, upperBound)
        width: parent.width
        contentHeight: column.height
        flickableDirection: Flickable.VerticalFlick
        clip: true
        interactive: contentHeight > flickable.height
        Column {
            id: column
            anchors {
                left: parent.left
                right: parent.right
                margins: 10
            }
            spacing: 10

            Common.Image {
                anchors.horizontalCenter: parent.horizontalCenter
                id: image
                source: img
                loadingRotate: true
                loadingSource: "qrc:///images/img_loading_badge_large.png"
            }
            Text {
                id: text
                anchors {
                    left: parent.left
                    right: parent.right
                }

                wrapMode: Text.Wrap
                text: description
                font.pixelSize: rootWindow.style.fontSmallSize
                color: "white"
            }

            Text {
                opacity: (usable && couponNum > 0)? 1 : 0
                anchors {
                    left: parent.left
                    right: parent.right
                }
                horizontalAlignment: Text.AlignHCenter
                text: qsTr("You have %1 coupons.").arg(couponNum)
                font.pixelSize: rootWindow.style.fontNormalSize
                color: "white"
            }

            // The "no more coupon to use" / "you have used the badge" text
            Rectangle {
                property bool show: usable && (couponNum <= 0 || justUsed)
                opacity: show ? 1 : 0
                anchors {
                    left: parent.left
                    right: parent.right
                }
                color: "lightgrey"
                radius: 5
                height: show ? couponUseText.height + 10 : 0

                Text {
                    id: couponUseText
                    anchors {
                        left: parent.left
                        right: parent.right
                        top: parent.top
                        margins: 5
                    }
                    font.pixelSize: rootWindow.style.fontNormalSize
                    horizontalAlignment: Text.AlignHCenter
                    text: justUsed ? qsTr("You have used the badge.") : qsTr("No more coupon to use.\nThanks")
                }
            }
        }
    }

    acceptButtonText: {
        if (showUseButton)
            return qsTr("Use This Badge");
        if (confirmMode)
            return qsTr("Confirm");
        return ""
    }
    rejectButtonText: !confirmMode ? qsTr("Close") : qsTr("Cancel")

    function accept() {
        if (!confirmMode) {
            confirmMode = true;
        } else {
            var url = "/badges/usecoupon.json"
            var args = {"id": badgeId}
            rootWindow.request(url, args, undefined, undefined, function(ret, obj) {
                justUsed = true;
                confirmMode = false;
                couponUsed(couponNum - 1);
            });
        }
    }

    function reject() {
        if (confirmMode) {
            confirmMode = false
        } else {
            close();
        }
    }
}

