import QtQuick 1.0
import Qt.labs.components.native 1.0

import "../Common" as Common

Common.Page {

    // Read/write properties
    property variant typeId
    property variant userId

    // private properties
    property bool busy: false
    property variant requestParams: {"type_id": typeId, "user_id": userId}
    property string requestUrl: "/badges/list.json"
    property variant model
    property int itemWidth: 80

    id: page

    Flickable {
        anchors {
            fill: parent
            margins: 10
        }
        contentHeight: grid.height
        clip: true
        Grid {
            id: grid
            anchors {
                left: parent.left
                right: parent.right
            }

            height: childrenRect.height

            columns: 4
            spacing: (width - itemWidth * 4) / 3
            Repeater {
                model: page.model
                delegate: Item {
                    width: itemWidth
                    height: column.height
                    Column {
                        id: column
                        width: parent.width
                        Common.Image {
                            anchors.horizontalCenter: parent.horizontalCenter
                            source: modelData.img
                            loadingRotate: true
                            loadingSource: "qrc:///images/img_loading_badge.png"
                        }
                        Text {
                            anchors.horizontalCenter: parent.horizontalCenter
                            width: parent.width
                            elide: Text.ElideRight
                            horizontalAlignment: Text.AlignHCenter
                            text: modelData.name
                            font.pixelSize: rootWindow.style.fontSmallSize
                        }
                    }
                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            showBadge(modelData)
                        }
                    }
                }
            }
        }
    }

    Rectangle {
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
        }
        height: 50 * rootWindow.style.scale
        opacity: busy? 1 : 0
        color: "lightgrey"
        Row {
            spacing: 7
            anchors.centerIn: parent
            BusyIndicator {
                id: loadingIndicator
                running: busy
                anchors.verticalCenter: parent.verticalCenter
            }

            Text {
                anchors.verticalCenter: parent.verticalCenter
                id: moreText
                text: qsTr("Loading...");
                font.pixelSize: rootWindow.style.fontNormalSize
            }
        }
    }
    onRequestParamsChanged: {
        refresh();
    }

    function showBadge(data) {
        var dialogComponent = Qt.createComponent("BadgeDialog.qml");
        var dialog = dialogComponent.createObject(page)
        dialog.badgeId = data.id
        dialog.img = data.large_img
        dialog.name = data.name
        dialog.usable = userId === rootWindow.user.userId && (data.coupon_type === 1 || data.coupon_type === 3)
        dialog.couponNum = data.coupon_num
        dialog.description = data.description
        dialog.couponUsed.connect(refresh)
        dialog.open()
    }

    function refresh() {
        if (!typeId || !userId)
            return;
        busy = true
        var onSuccess = function(ret, obj) {
            busy = false;
            model = obj;
        };
        var onError = function(ret, obj) {
            busy = false;
        };

        rootWindow.request(requestUrl, requestParams, null, undefined,
                           onSuccess, onError);
    }
}
