import QtQuick 1.0
import Qt.labs.components.native 1.0

import "../Common" as Common
import "../Common/Network.js" as Network

Common.Page {
    property variant userId

    id: page

    Common.List {
        id: listView
        anchors.fill: parent
        requestUrl: "/badges/summary.json"
        requestParams: {"user_id": userId}
        canGetMore: false

        delegate: Common.ListItem {
            id: listItem

            content: Item {
                height: row.height
                Text {
                    anchors {
                        left: parent.left
                        right: row.left
                        verticalCenter: parent.verticalCenter
                    }
                    text: model.name
                    font.pixelSize: rootWindow.style.fontNormalSize
                }

                Row {
                    id: row
                    spacing: 10
                    height: childrenRect.height
                    anchors {
                        right: moreImage.left
                        margins: 10
                    }

                    Common.Image {
                        source: (model.latest_badges_0)? model.latest_badges_0.img : ""
                        defaultSource: "qrc:///images/img_default_badge.png"
                        loadingSource: "qrc:///images/img_loading_badge.png"
                        loadingRotate: true
                    }
                    Common.Image {
                        source: (model.latest_badges_1)? model.latest_badges_1.img : ""
                        defaultSource: "qrc:///images/img_default_badge.png"
                        loadingSource: "qrc:///images/img_loading_badge.png"
                        loadingRotate: true
                    }
                    Common.Image {
                        source: (model.latest_badges_2)? model.latest_badges_2.img : ""
                        defaultSource: "qrc:///images/img_default_badge.png"
                        loadingSource: "qrc:///images/img_loading_badge.png"
                        loadingRotate: true
                    }
                }
                Image {
                    id: moreImage
                    anchors {
                        right: parent.right
                        verticalCenter: row.verticalCenter
                    }
                    source: "qrc:///images/badge_item_more.png"
                }
            }

            onClicked: {
                rootWindow.pushPage(Qt.resolvedUrl("BadgesPage.qml"),
                                    {"userId": userId,
                                     "typeId": model.id})
            }
        }
        section.property: "category"

        section.delegate: Rectangle {
            id: listHeading
            width: (parent)? parent.width : 0
            height: childrenRect.height + 10

            color: "#dbdbdb"
            Text {
                y: 5
                anchors {
                    left: parent.left
                    leftMargin: 10;
                }
                text: section
                font.pixelSize: rootWindow.style.fontNormalSize
            }
        }

        function parseResult(result, model) {
            for (var i = 0; i < result.length; i++)
                parseSummary(result[i], model, null);
        }
    }

    function parseSummary(obj, model, category) {
        if (!category)
            category = obj.name

        // This is a hack because QML doesn't support lists in the models.
        // So we move the latest_badges into attributes.
        for(var i = 0; i < 4; i++)
            obj["latest_badges_" + i] = null
        if (obj.latest_badges !== undefined) {
            for (var i = 0; i < obj.latest_badges.length; i++) {
                obj["latest_badges_" + i] = obj.latest_badges[i]
            }
        }

        if (obj.num_badges_got !== undefined && obj.num_badges_got > 0) {
            obj.category = category
            model.append(obj)
        }

        if (obj.children !== undefined) {
            for (var i = 0; i < obj.children.length; i++) {
                parseSummary(obj.children[i], model, category)
            }
        }
    }
}
