import QtQuick 1.0
import Qt.labs.components.native 1.0

import "../Common" as Common
import "../Common/Network.js" as Network
import JiePang 1.0

Common.Page {
    property variant guid
    property variant longitude
    property variant latitude
    property variant nfcKey

    property Item uploadDialog;
    // Just used to check if a page if a checking page!
    property string pageName: "CheckinPage"
    title: qsTr("Check-in")

    id: page

    function showObj(obj)
    {
        for(var i in obj) {
            console.debug(i + ":" + obj.i)
            showObj(i);
        }
    }

    function handleCutted(offsetX, offsetY, cutWidth, previewWidth, rota, path) {
        var savePath = photoUploader.loadFile(path, offsetX, offsetY, cutWidth, previewWidth, rota)
        console.debug("savePath=" + savePath)
        textArea.imageSource = savePath;
    }

    function handleProgress(v) {
        console.debug("progress=" + v)
        uploadDialog.updateProgress(v);
    }

    function handleFinished(result) {
        uploadDialog.close();
        var obj = JSON.parse(result, Network.jsonReviver)
        rootWindow.refreshFeeds();
        var summaryPage = pageStack.replace(Qt.resolvedUrl("CheckInSummaryPage.qml"),
                           {"locationName": obj.location.name,
                            "userCheckinNum": obj.location.user_checkin_num,
                            "userLastCheckinTime": obj.user_last_checkin_time,
                            "points": obj.points,
                            "badges": obj.badges});
        summaryPage.showBadges();
    }

    function handleUploadFailed(error) {
        var confirmDialog = confirmDialogComponent.createObject(pageStack.currentPage)
        var obj = JSON.parse(error, Network.jsonReviver);
        console.debug("upload Fail:" + error)
        uploadDialog.close();
        confirmDialog.body = obj.error.message;
        confirmDialog.open();
    }

    PhotoUploader {
        id: photoUploader;

    }

    Common.ImageTextArea {
        id: textArea
        anchors {
            top: parent.top
            left: parent.left
            right: parent.right
            margins: 10
        }
        onImageClicked: {
            var cameraPage = pageStack.push(Qt.resolvedUrl("CameraPage.qml"))
            cameraPage.cutted.connect(page.handleCutted)
        }
    }

    Common.Button {
        id: checkinButton
        anchors.top: textArea.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.margins: 10
        text: qsTr("Check-in")

        function checkInWithPicture() {
            uploadDialog = uploadDialogComponent.createObject(page)
            uploadDialog.open();
            photoUploader.failled.connect(handleUploadFailed);
            photoUploader.finished.connect(handleFinished);
            photoUploader.progressed.connect(handleProgress);
            var url = Network.server + "/lbs/checkin.json";
            photoUploader.doUpload((textArea.imageSource === undefined
                                    || textArea.imageSource === "") ? false : true
                                   , url
                                   , Network.credentials, guid, textArea.text
                                   , syncsList.getString(), privateCheckinBox.checked
                                   , Network.source, latitude, longitude
                                   , nfcKey !== undefined ? nfcKey : "");
        }

        function checkInWithoutPicture() {
            var url = "/lbs/checkin.json"
            var params = {"status": textArea.text.replace('&', '%26'),
                "lat": latitude, "lon": longitude, "use_new_points": 1,
                "guid": guid, "syncs": syncsList.getString()}
            if (privateCheckinBox.checked)
                params["privacy"] = 1
            if (nfcKey !== undefined)
                params["nfc_key"] = nfcKey;
            rootWindow.request(url, params, qsTr("Checking-in"), qsTr("Cannot checkin"), function(ret, obj) {
                rootWindow.refreshFeeds();
                var summaryPage = pageStack.replace(Qt.resolvedUrl("CheckInSummaryPage.qml"),
                                   {"locationName": obj.location.name,
                                    "userCheckinNum": obj.location.user_checkin_num,
                                    "userLastCheckinTime": obj.user_last_checkin_time,
                                    "points": obj.points,
                                    "badges": obj.badges});
                summaryPage.showBadges();
            });
        }

        onClicked: {
            if (textArea.imageSource) {
                checkInWithPicture();
            } else {
                checkInWithoutPicture();
            }
        }
    }

    CheckBox {
        id: privateCheckinBox
        anchors.top: checkinButton.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.margins: 10
        text: qsTr("Private check-in")
    }

    Common.SyncsCheckBoxes {
        id: syncsList
        anchors {
            top: privateCheckinBox.bottom
            bottom: parent.bottom
            left: parent.left
            right: parent.right
            margins: 10
        }
        color: "#ebebeb"
        enabled: !privateCheckinBox.checked
        allUnchecked: privateCheckinBox.checked
        model: rootWindow.user.syncsSetting
    }
    Component {
        id: uploadDialogComponent
        Dialog {
            function updateProgress(v) {
                progressBar.value = v * 100
            }

            id: uploadDialog
            title: Text {text: qsTr("Uploading...")}

            content: ProgressBar {
                id: progressBar
                anchors {
                    left: parent.left
                    right: parent.right
                    margins: 10
                    verticalCenter: parent.verticalCenter
                }

                minimumValue: 0
                maximumValue: 100
                value: 0
                indeterminate: value == maximumValue ? "true" : "false"
            }
        }
    }
    Component {
        id: confirmDialogComponent
        QueryDialog {
            property string body;
            titleText: qsTr("Failed")
            message: (body === "" || body === undefined) ? qsTr("Failed") : body
            acceptButtonText: qsTr("OK")
        }
    }
}
