import QtQuick 1.0
import Qt.labs.components.native 1.0

import "../Common" as Common
import "../Common/Network.js" as Network

Common.Page {
    property string locationName
    property int userCheckinNum
    property variant userLastCheckinTime
    property variant points
    property variant badges
    property variant message

    id: page

    // Add a 'l' after a file name (before the png extension).
    function getLargeBagdeImage(url) {
        var name = url.split('.png')[0];
        return name + 'l.png';
    }

    function getCouponImage(type) {
        switch(type) {
        case 1:
            return "qrc:///images/ic_jpcoupon_group.png"
            break;
        case 2:
            return "qrc:///images/ic_jpcoupon_first.png"
            break;
        case 3:
            return "qrc:///images/ic_jpcoupon_checkin.png"
            break;
        case 4:
            return "qrc:///images/ic_jpcoupon_royal.png"
            break
        }
    }

    function showBadges() {
        // Show all the badges in popup dialogs.
        var i = 0;
        var show = function() {
            if (badges.length <= i)
                return;
            var badge = badges[i];
            var dialogComponent = Qt.createComponent("BadgeDialog.qml");
            var dialog = dialogComponent.createObject(page);
            dialog.badgeId = badge.id;
            dialog.usable = badge.coupon_type === 1 || badge.coupon_type === 3
            dialog.couponNum = badge.coupon_num
            if (badge.id.indexOf("_") !== -1) { // This is a coupon
                dialog.img = getCouponImage(badge.type);
            } else {
                dialog.img = getLargeBagdeImage(badge.img);
            }
            dialog.name = badge.name;
            dialog.description = badge.description;
            dialog.accepted.connect(function() {i++; show()});
            dialog.open();
        }
        show();
    }

    function getText(name, checkinNum, lastTime) {
        var text;
        if (checkinNum === 1) {
            text = qsTr("Hi! You are at %1, and have checked in here 1 time!");
            return text.arg(name);
        } else {
            if (lastTime === undefined)
                return ""
            text = qsTr("Hi! You are at %1, and have checked in here %2 times! last time is %3");
            var dateText = "" + Qt.formatDateTime(lastTime, "yyyy-MM-dd");
            return text.arg(name).arg(checkinNum).arg(dateText);
        }
    }
    function totalPoints(points) {
        if (points === undefined)
            return undefined
        var total = 0;
        for (var i = 0; i < points.length; i++)
            total += points[i].points;
        return total;
    }

    // XXX: use a list instead here.
    Flickable {
        anchors.fill: parent
        contentHeight: column.height + 10
        clip: true
        Column {
            id: column
            anchors.horizontalCenter: parent.horizontalCenter;
            width: parent.width
            spacing: 10
            Text {
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.margins: 10
                font.pixelSize: rootWindow.style.fontNormalSize
                text: getText(locationName, userCheckinNum, userLastCheckinTime)
                wrapMode: Text.Wrap
            }
            Rectangle {
                id: listHeading
                width: parent.width
                height: childrenRect.height + 10
                color: "#dbdbdb"
                Text {
                    anchors {
                        top: parent.top
                        topMargin: 5
                        left: parent.left
                        leftMargin: 10;
                    }
                    text: qsTr("Checkin Points")
                    font.pixelSize: rootWindow.style.fontNormalSize
                }
            }

            Repeater {
                model: points

                delegate: Item {
                    height: childrenRect.height
                    width: column.width
                    Common.Image {
                        id: image
                        imageHeight: 16
                        imageWidth: 16
                        anchors.left: parent.left
                        anchors.verticalCenter: text.verticalCenter
                        anchors.margins: 10
                        source: modelData.icon
                    }

                    Text {
                        id: text
                        anchors.left: image.right
                        anchors.right: pointsText.left
                        anchors.margins: 10
                        wrapMode: Text.Wrap
                        text: modelData.message
                        font.pixelSize: rootWindow.style.fontNormalSize
                    }

                    Text {
                        id: pointsText
                        anchors.right: parent.right
                        anchors.margins: 10
                        text: "+" + modelData.points
                        font.pixelSize: rootWindow.style.fontNormalSize
                    }
                }
            }
            Item {
                width: parent.width
                height: childrenRect.height
                Text {
                    anchors.left: parent.left
                    anchors.leftMargin: 10
                    text: qsTr("Total Points")
                    font.pixelSize: rootWindow.style.fontNormalSize
                }
                Text {
                    anchors.right: parent.right
                    anchors.margins: 10
                    text: "+" + totalPoints(points)
                    font.pixelSize: rootWindow.style.fontNormalSize
                }
            }

            Rectangle {
                height: childrenRect.height + 10
                color: "#dbdbdb"
                width: parent.width
                visible: (message === undefined) ? false : true;
                Text {
                    anchors {
                        top: parent.top
                        topMargin: 5
                        left: parent.left
                        leftMargin: 10
                    }
                    text: qsTr("Tips")
                    font.pixelSize: rootWindow.style.fontNormalSize
                }
            }
            Item {
                width: parent.width
                height: childrenRect.height
                Text {
                    anchors.left: parent.left
                    anchors.right: parent.right
                    anchors.margins: 10+16
                    wrapMode: Text.WordWrap
                    text: (message === undefined) ? "" : message;
                    font.pixelSize: rootWindow.style.fontNormalSize
                }
            }
        }
    }
}
