import QtQuick 1.0
import Qt.labs.components.native 1.0
import "../Common" as Common

Common.Page {
    property alias menu: menuComponent
    property variant longitude
    property variant latitude
    property bool error
    property int distance: 500

    id: page

    headerButtons {
        Common.ImageButton {
            fillMode: Image.PreserveAspectFit
            anchors.right: header.right
            id: distanceSelectBtn
            imageHeight: header.height
            scale: 1
            smooth: true
            source: "qrc:///images/img_head_btn_bg.9.png"
            pressedSource: "qrc:///images/img_head_btn_bg_pressed.9.png"
            onClicked: distanceDialog.open();
            Text {
                id: distanceText;
                anchors.centerIn: parent
                color: "white"
                text: qsTr("%1m").arg(distance)
                font.pixelSize: parent.height * 0.3
            }
            SelectionDialog {
                id: distanceDialog
                titleText: qsTr("Select")
                selectedIndex: 0

                // XXX: we cannot use qsTr here, because of
                // https://bugreports.qt.nokia.com//browse/QTBUG-16289.
                // I just don't use it for the moment but we will need to
                // find a workaround! (e.g, a different model for chinese?)
                model: ListModel {
                    ListElement { value: 500; name: "500m"}
                    ListElement { value: 1000; name: "1000m"}
                    ListElement { value: 2000; name: "2000m"}
                }

                onSelectedIndexChanged: {
                    distance = model.get(selectedIndex).value;
                }
            }
        }
    }

    Common.List {
        anchors.fill: parent
        canGetMore: false
        delegate: Common.MenuItem {
            text: model.name
            nb: model.nb
            images: [model.image_0, model.image_1, model.image_2]

            onClicked: {
                switch (model.type) {
                case "friends":
                    rootWindow.pushPage(Qt.resolvedUrl("ExploreFriendsPage.qml"),
                                        {"longitude": longitude, "latitude": latitude, "distance": distance});
                    break;
                case "coupons":
                    rootWindow.pushPage(Qt.resolvedUrl("ExploreCouponsPage.qml"),
                                        {"longitude": longitude, "latitude": latitude, "distance": distance});
                    break;
                case "tipsfeatured":
                    rootWindow.pushPage(Qt.resolvedUrl("ExploreTipsPage.qml"),
                                        {"longitude": longitude, "latitude": latitude, "distance": distance,
                                         "maxCount": model.nb});
                    break;
                }
            }
        }

        requestUrl: "/discover/summary.json"
        requestParams: {"lon": longitude, "lat": latitude, "dist": distance}
        section.property: "category"

        function parseResult(result, model) {
            var friendModel = {
                "type": "friends",
                "category": qsTr("Friends"),
                "nb": result.friends_checkins_users.length};
            for (var i = 0; i < result.friends_checkins_users.length; i++) {
                friendModel["image_%1".arg(i)] = result.friends_checkins_users[i].avatar_thumb
            }
            if (result.friends_checkins_users.length > 0)
                friendModel['name'] = "";
            else
                friendModel['name'] = qsTr("No friends's check-in nearby");

            model.append(friendModel);
            model.append({"name": qsTr("Coupons"),
                         "type": "coupons",
                         "category": qsTr("Coupons"),
                         "nb": result.coupon_venues_count});
            model.append({"name": qsTr("Featured"),
                         "type": "tipsfeatured",
                         "category": qsTr("Tips"),
                         "nb": result.great_tips_count});
        }
        Component {
            id: menuComponent
            Menu {
                MenuLayout {
                    MenuItem {
                        text: qsTr("Refresh")
                        onClicked: {
                            page.refresh();
                        }
                    }
                    MenuItem {
                        text: qsTr("More")
                        onClicked: {
                            rootWindow.pushPage(Qt.resolvedUrl("MorePage.qml"));
                        }
                    }
                    MenuItem {
                        text: qsTr("Quit")
                        property QueryDialog queryDialog
                        onClicked: {
                            if (!queryDialog)
                                queryDialog = quitDialogComponent.createObject(page);
                            queryDialog.open();
                            queryDialog.accepted.connect(Qt.quit);
                        }
                    }
                }
            }
        }
    }
}
