import QtQuick 1.0
import Qt.labs.components.native 1.0

import "../Common" as Common
import "../Common/Network.js" as Network

Common.Page {
    id: page
    property variant postId
    property string type
    property variant user
    property variant userId
    property variant body
    property variant location
    property variant locationId
    property date date
    property variant numLikes
    property bool isLike: false
    property variant commentCount
    property variant photo
    property url avatar: ""
    property variant source
    property variant userFollow

    property bool busy: false // XXX: tmp fix for this release, we should use Request item, weiwu is working on that.

    signal updated(int numLikes, bool isLike, int commentCount);


    function handleResult(state, obj) {
        page.busy = false;
        if(state !== 200 && obj.error !== undefined) {
            rootWindow.showDialog(qsTr("Error"), obj.error.message);
        } else {
            type = obj.type
            user = obj.user.nick
            body = obj.body
            if(obj.location !== undefined) {
                location = obj.location.name
                locationId = obj.location.guid
            }
            date = obj.created_on
            numLikes = obj.num_likes
            isLike = obj.is_like
            commentCount = obj.num_comments
            avatar = obj.user.avatar
            source = obj.source.name
            if(obj.photo) {
                photo = obj.photo.url;
            }
            commentsList.errorMessage =
                    (commentCount === 0)? qsTr("No comment yet") : undefined;
        }
    }

    function refreshFeedInfo() {
        page.busy = true;
        Network.doPost("/statuses/show.json", {"apiver": 2, "id": postId}
                       , handleResult);
    }

    function refresh() {
        refreshFeedInfo();
        likeUsersList.refresh()
        commentsList.refresh()
    }
    // private properties
    function likesText(numLikes, isLike) {
        if (numLikes === 0)
            return qsTr("Nobody likes it");
        if (numLikes === 1 && isLike)
            return qsTr("I like it");
        if (!isLike)
            return qsTr("%1 people like it").arg(numLikes);
        return qsTr("%1 people & I like it").arg(numLikes - 1);
    }

    Flickable {
        anchors {
            top: parent.top
            left: parent.left
            right: parent.right
            bottom: commentInput.top
        }

        contentHeight: column.height + 10
        clip: true

        Column {
            spacing: 10
            id: column
            anchors {
                top: parent.top
                topMargin: 10
                left: parent.left;
                right: parent.right
            }
            Common.Item {
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                width: parent.width
                type: page.type
                postId: page.postId
                user: page.user
                userId: page.userId
                body: page.body
                location: page.location
                locationId: page.locationId
                date: page.date
                // numLikes: page.numLikes
                // commentCount: page.commentCount
                avatar: page.avatar
                source: page.source
                userFollow: page.userFollow
            }

            Common.Image {
                source: (photo !== undefined)? photo + "?size=300" : ""
                defaultSource: "qrc:///images/loading300.png"
                opacity: (photo !== undefined)? 1 : 0
                imageWidth: parent.width
                imageHeight: parent.width
                scale: 1
            }

            Rectangle {
                width: parent.width
                height: likeButton.height + 10
                color: "#dbdbdb"
                Text {
                    anchors {
                        verticalCenter: parent.verticalCenter
                        left: parent.left
                        leftMargin: 10;
                    }
                    font.pixelSize: rootWindow.style.fontNormalSize
                    text: likesText(numLikes, isLike)
                }
                BusyIndicator {
                    id: likeBusyIndicator
                    height: 30
                    width: 30
                    opacity: 0
                    anchors {
                        verticalCenter: parent.verticalCenter
                        right: likeButton.left
                        margins: 10
                    }
                    running: true
                }

                Common.ImageButton {
                    id: likeButton
                    anchors {
                        verticalCenter: parent.verticalCenter
                        right: parent.right
                        rightMargin: 10
                    }
                    source: (isLike)? "qrc:///images/like_btn_on.png" : "qrc:///images/like_btn_off.png"
                    pressedSource: "qrc:///images/like_btn_press.png"
                    onClicked: {
                        likeBusyIndicator.opacity = 1;
                        likeButton.enabled = false;
                        var url = "/statuses/like.json"
                        var args = {"post_id": page.postId, "status": (isLike)? 0 : 1}
                        var onSuccess = function(ret, obj) {
                            likeBusyIndicator.opacity = 0;
                            likeButton.enabled = true;
                            if (ret === 200) {
                                isLike = !isLike;
                                numLikes += (isLike)? 1 : -1;
                                likeUsersList.refresh()
                                updated(page.numLikes, page.isLike, page.commentCount);
                            }
                        }
                        var onError = function(ret, obj) {
                            likeBusyIndicator.opacity = 0;
                            likeButton.enabled = true;
                        }
                        rootWindow.request(url, args, null, undefined, onSuccess, onError);
                    }
                }
            }

            Common.List {
                id: likeUsersList
                height: (model.count > 0)? 50 * rootWindow.style.scale : 0
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.right: parent.right
                anchors.rightMargin: 10
                orientation: ListView.Horizontal
                opacity: (numLikes === 0)? 0 : 1
                spacing: 5

                requestParams: {"id": page.postId}
                requestUrl: "/statuses/get_like_users"

                // Actually this should be called in the context of the feed, not just the like user list.
                // This is not good that we have to call this twice.
                function parseResult(result, model) {
                    page.numLikes = result.likes.length
                    for (var i=0; i < result.likes.length; i++) {
                        model.append(result.likes[i])
                    }
                }

                delegate: Common.Image {
                    source: model.avatar_thumb
                    defaultSource: "qrc:///images/img_nopic_thumb.png"
                    background: "qrc:///images/bg_avatar.png"
                    imageHeight: 45
                    imageWidth: 45

                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            rootWindow.pushPage(Qt.resolvedUrl("UserProfilePage.qml"),
                                                {"userId": model.id,
                                                "avatar": model.avatar_small,
                                                "userNick": model.nick})
                        }
                    }
                }
                footer: null
            }
            Rectangle {
                width: parent.width
                height: 45
                color: "#dbdbdb"
                Text {
                    anchors {
                        verticalCenter: parent.verticalCenter
                        left: parent.left
                        leftMargin: 10;
                    }
                    font.pixelSize: rootWindow.style.fontNormalSize
                    text: qsTr("Comments")
                }
            }

            Common.List {
                id: commentsList
                width: parent.width
                //                                    maxCount: page.commentCount
                // TODO: the +15 is a hack to ensure the loading indicator
                //      is visible. We should try to fix that.
                height: childrenRect.height + 15 * rootWindow.style.scale
                interactive: false
                requestParams: {"id": page.postId}
                requestUrl: "/statuses/get_comments"
                showLoading: loading || page.busy
                countParam: "" // We get all the comments
                canGetMore: false

                function parseResult(result, model) {
                    page.commentCount = result.length
                    for (var i=0; i < result.length; i++) {
                        model.append(result[i])
                    }
                    errorMessage = (result.length === 0)? qsTr("No comment yet") : undefined;
                }

                delegate: Common.ListItem {
                    content: Common.Item {
                        type: "comment"
                        user: model.u_nick
                        body: model.p_body
                        avatar: model.u_avatar_thumb
                        date: model.p_created_on
                    }
                    onClicked: {
                        commentText.text = qsTr("Reply to %1:").arg(model.u_nick);
                        commentText.openSoftwareInputPanel();
                    }
                    onPressAndHold: {
                        contextMenu.open();
                    }

                    ContextMenu {
                        id: contextMenu
                        MenuLayout {
                            MenuItem {
                                text: qsTr("Reply to %1").arg(model.u_nick);
                                onClicked: {
                                    commentText.text = qsTr("Reply to %1:").arg(model.u_nick);
                                    commentText.openSoftwareInputPanel();
                                }
                            }
                            MenuItem {
                                text: qsTr("View %1's profile").arg(model.u_nick);
                                onClicked: {
                                    rootWindow.pushPage(Qt.resolvedUrl("UserProfilePage.qml"),
                                                        {"userId": model.u_id,
                                                        "avatar": model.u_avatar_small,
                                                        "userNick": model.u_nick});
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    Rectangle {
        id: commentInput
        color: "#dbdbdb"
        height: 70

        anchors {
            left: parent.left
            right: parent.right
            bottom: parent.bottom
        }

        TextField {
            id: commentText
            anchors {
                left: parent.left
                leftMargin: 10
                right:  commentSendButton.left
                rightMargin: 10
                top: parent.top
                topMargin: 10
                bottom: parent.bottom
                bottomMargin: 10
            }
            placeholderText: qsTr("Input reply message")
        }

        Button {
            id: commentSendButton
            anchors {
                top: parent.top
                topMargin: 10
                right: parent.right;
                rightMargin: 10
                bottom: parent.bottom
                bottomMargin: 10
            }
            style : ButtonStyle {buttonWidth: 100}

            text: qsTr("Send")

            onClicked: {
                var comment = commentText.text.replace('&', '%26');
                commentText.text = "";
                var url = "/statuses/comment.json";
                var args = {"comment": comment, "reply_post_id": page.postId};
                rootWindow.request(url, args, null, null, function(ret, obj) {
                                       commentCount += 1;
                                       commentsList.refresh()
                                       updated(page.numLikes, page.isLike, page.commentCount);
                                   });
            }
        }
    }
    onStatusChanged: {
        if (status === PageStatus.Activating) {
            refreshFeedInfo();
        }
    }
}

