import QtQuick 1.0
import Qt.labs.components.native 1.0
import "../Common" as Common

Common.Page {
    id: page
    property variant userId
    property variant count

    Common.List {
        id: list
        anchors.fill: parent

        requestUrl: "/friends/invitations.json"
        requestParams: {"apiver": 2}
        usePages: true
        maxCount: page.count

        headerText: (page.count !== undefined) ? qsTr("You have %1 friend requests").arg(page.count) : ""


        delegate: Common.ListItem {
            id: listItem
            allowClick: true
            content: Item {
                id: item
                property string message

                anchors {
                    left: parent.left
                    right: parent.right
                }
                height: childrenRect.height

                Common.Image {
                    anchors.left: parent.left
                    id: image
                    source: model.avatar_thumb
                    defaultSource: "qrc:///images/img_nopic_thumb.png"
                }
                Column {
                    id: textsColumn
                    anchors {
                        left: image.right
                        right: messageText.left
                        top: parent.top
                        leftMargin: 10
                        rightMargin: 10
                    }
                    // TODO: set the proper color
                    Text {
                        color: "lightblue"
                        text: model.nick
                        font.pixelSize: rootWindow.style.fontNormalSize
                    }
                    Text {
                        text: model.message
                        width: parent.width
                        wrapMode: Text.Wrap
                        font.pixelSize: rootWindow.style.fontNormalSize
                    }
                }

                Text {
                    id: messageText
                    text: item.message
                    font.pixelSize: rootWindow.style.fontNormalSize
                    anchors {
                        right: acceptBtn.left
                        top: parent.top
                        margins: 10
                    }
                }

                Common.ImageButton {
                    id: acceptBtn
                    anchors {
                        right: declineBtn.left
                        top: parent.top
                        margins: 10
                    }
                    opacity: (item.message)? 0 : 1
                    source: "qrc:///images/img_accept.png"
                    pressedSource: source
                    onClicked: {
                        var url = "/friends/reply.json"
                        var args = {id: model.id, reply: 1};
                        var onResult = function(ret, obj) {
                            item.message = qsTr("Accepted");
                        }
                        rootWindow.request(url, args, undefined, undefined, onResult);
                    }
                }
                Common.ImageButton {
                    id: declineBtn
                    anchors {
                        right: parent.right
                        top: parent.top
                        margins: 10
                    }
                    opacity: (item.message)? 0 : 1
                    source: "qrc:///images/img_decline.png"
                    pressedSource: source
                    onClicked: {
                        var url = "/friends/reply.json"
                        var args = {id: model.id, reply: 2};
                        var onResult = function(ret, obj) {
                            item.message = qsTr("Ignored");
                        }
                        rootWindow.request(url, args, undefined, undefined, onResult);
                    }
                }
            }

            onClicked: {
                rootWindow.pushPage(Qt.resolvedUrl("UserProfilePage.qml"),
                                    {"userId": model.id,
                                     "avatar": model.avatar_small,
                                     "userNick": model.nick})
            }
        }

        function parseResult(result, model) {
            page.count = result.count;
            var invitations = result.invitations;
            for (var i = 0; i < invitations.length; i++) {
                model.append(invitations[i]);
            }
        }
    }
}
