import QtQuick 1.0
import Qt.labs.components.native 1.0

import "../Common" as Common

Common.Page {
    property alias menu: menuComponent
    property variant userId

    id: page
    width: parent.width

    function refresh() {
        list.refresh()
    }

    headerButtons {
        Common.ImageButton  {
            fillMode: Image.PreserveAspectFit
            anchors.right: parent.right
            id: checkinBtn
            imageHeight: header.height
            scale: 1
            source: "qrc:///images/img_head_btn_checkin2.9.png"
            pressedSource: "qrc:///images/img_head_btn_checkin2_pressed.9.png";
            Text {
                text:qsTr("Check-in")
                color: "white"
                x: parent.width * 0.5
                anchors.verticalCenter: parent.verticalCenter;
                font.pixelSize: parent.height * 0.5
            }
            onClicked: rootWindow.showPlacesTab()
        }
    }

    Common.List {
        id: list
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
            bottom: parent.bottom
        }

        requestUrl: "/events/friends_timeline.json"
        requestParams: {"types": "1,2,3,5,6,7,8", "id": page.userId}
        initialCount: 20
        moreCount: 10
        usePages: false

        delegate: Common.ListItem {
            content: Common.Item {
                id: item
                postId: model.remark.p_id
                type: model.type_name
                user: model.remark.u_nick
                userId: model.remark.u_id
                userFollowId: model.remark.u_f_id
                userFollow: model.remark.u_f_nick
                location: model.remark.l_name
                locationId: model.remark.l_guid
                body: model.remark.p_body
                photo: (model.remark.p_photo)? model.remark.p_photo.url : undefined
                avatar: model.remark.u_avatar_small
                numLikes: model.remark.p_num_likes
                isLike:  model.remark.p_is_like
                commentCount: model.remark.p_comment_count
                date: model.created_on
                // source: model.source.name
            }

            onClicked: {
                item.show();
            }
        }

        // Function that is used to fill the model from the server result.
        function parseResult(result, model) {
            for (var i = 0; i < result.length; i++) {
                var obj = result[i];
                model.append(obj)
            }
        }
        Rectangle {
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right
            height: 15
            gradient: Gradient {
                GradientStop {
                    position: 1.0
                    color: "#00ebebeb"
                }
                GradientStop {
                    position: 0.0
                    color: "#efebebeb"
                }
            }
        }
        Rectangle {
            anchors.bottom: parent.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            height: 15
            gradient: Gradient {
                GradientStop {
                    position: 0.0
                    color: "#00ebebeb"
                }
                GradientStop {
                    position: 1.0
                    color: "#ffebebeb"
                }
            }
        }
    }

    Component {
        id: menuComponent
        Menu {
            MenuLayout {
                MenuItem {
                    text: qsTr("Check-in")
                    onClicked: {
                        rootWindow.showPlacesTab();
                    }
                }
                MenuItem {
                    text: qsTr("Shout")
                    onClicked: {
                        rootWindow.pushPage(Qt.resolvedUrl("ShoutPage.qml"));
                    }
                }
                MenuItem {
                    text: qsTr("Refresh")
                    onClicked: {
                        page.refresh();
                    }
                }

                MenuItem {
                    text: qsTr("More")
                    onClicked: {
                        rootWindow.pushPage(Qt.resolvedUrl("MorePage.qml"));
                    }
                }
                MenuItem {
                    text: qsTr("Quit")
                    property QueryDialog queryDialog
                    onClicked: {
                        if (!queryDialog)
                            queryDialog = quitDialogComponent.createObject(page);
                        queryDialog.open();
                        queryDialog.accepted.connect(Qt.quit);
                    }
                }
            }
        }
    }
}
