import QtQuick 1.0
import Qt.labs.components.native 1.0

import "../Common" as Common

Common.Page {
    id: page

    property variant guid
    property string name
    property string addr
    property variant longitude
    property variant latitude
    property variant mayor
    property bool hasCoupon: false
    property string city

    property variant additionalCoupons: []

    function isNeedShifted() {
        switch(city)
        {
        case "香港": return true;
        default: return false;
        }
    }

    headerButtons {
        Common.ImageButton {
            imageHeight: header.height;
            fillMode: Image.PreserveAspectFit
            scale: 1
            anchors.right: parent.right
            smooth: true
            source: "qrc:///images/img_head_btn_heresurprise.9.png"
            pressedSource: "qrc:///images/img_head_btn_heresurprise_pressed.9.png"
            opacity: hasCoupon ? 1 : 0
            onClicked: {
                print("page gui", page.guid)
                rootWindow.pushPage(Qt.resolvedUrl("LocationCouponsPage.qml"),
                                    {"guid": page.guid,
                                     "locationName": page.name,
                                     "additionalCoupons": page.additionalCoupons});
            }

            Text {
                text:qsTr("Surprise")
                color: "white"
                x: parent.width * 0.5
                anchors.verticalCenter: parent.verticalCenter;
                font.pixelSize: parent.height * 0.5
            }
        }
    }


    Rectangle {
        color: "#dbdbdb"
        id: titleRectangle
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        height: childrenRect.height + 20

        Column {
            id: addrItem
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.margins: 10
            spacing: 10
            Text {
                text: name
                elide: Text.ElideRight
                width: parent.width
                color: "#3b3b3b"
                font.pixelSize: rootWindow.style.fontNormalSize
            }
            Text {
                text: addr
                width: parent.width
                wrapMode: "WordWrap"
                color: "#898989"
                font.pixelSize: rootWindow.style.fontSmallSize
            }
        }
        Common.Button {
            id: checkInButton
            anchors {
                left: parent.left
                right: parent.right
                top: addrItem.bottom
                margins: 10
            }
            text: qsTr("Check-in")
            onClicked: {
                rootWindow.pushPage(Qt.resolvedUrl("CheckInPage.qml"),
                                    {"guid": page.guid,
                                     "longitude": page.longitude,
                                     "latitude": page.latitude});
            }
        }
    }

    Common.List {
        id: list
        anchors {
            top: titleRectangle.bottom
            bottom: parent.bottom
            left: parent.left
            right: parent.right
        }

        maxCount: 2

        delegate: Common.MenuItem {
            id: item
            text: model.name
            nb: model.nb
            icon: model.icon
            avatar: model.avatar

            onClicked: {
                // The only way not to mix page.name with the model name is to use the
                // ugly: ListView.view.parent.name.
                switch (model.type) {
                case "mayor":
                    rootWindow.pushPage(Qt.resolvedUrl("UserProfilePage.qml"),
                                        {"userId": mayor.id,
                                         "avatar": mayor.avatar_small,
                                         "userNick": mayor.nick});
                    break;
                case "visitors":
                    rootWindow.pushPage(Qt.resolvedUrl("LocationVisitorsPage.qml"),
                                        {"maxCount": model.nb, "guid": guid,
                                         "name": ListView.view.parent.name,
                                         "mayor": ListView.view.parent.mayor});
                    break;
                case "tips":
                    rootWindow.pushPage(Qt.resolvedUrl("LocationTipsPage.qml"),
                                        {"maxCount": model.nb, "guid": guid, "name": ListView.view.parent.name});
                    break;
                case "photos":
                    rootWindow.pushPage(Qt.resolvedUrl("LocationGalleryPage.qml"),
                                        {"maxCount": model.nb, "guid": guid, "name": ListView.view.parent.name});
                    break;
                case "map":
                    rootWindow.pushPage(Qt.resolvedUrl("MapPage.qml"),
                                        {"longitude": longitude, "latitude": latitude, "needShift": isNeedShifted()});
                    break;
                }
            }
        }

        requestUrl: "/locations/counts.json"
        requestParams: {"guid": guid}
        usePages: false
        autoRefresh: false

        // Function that is used to fill the model from the server result.
        function parseResult(result, model) {
            if (mayor)
                model.append({type: "mayor",
                              name: qsTr("%1\nis the mayor here").arg(mayor.nick),
                              icon: "qrc:///images/img_no_mayor.png",
                              nb: undefined,
                              avatar: mayor.avatar_thumb});
            else
                model.append({type: "",
                              name: qsTr("No mayor at the moment. Check-in to be the mayor now!"),
                              icon: "qrc:///images/img_no_mayor.png",
                              nb: undefined});
            model.append({type: "visitors",
                          name: qsTr("Visitors"),
                          icon: "qrc:///images/ic_visitor.png",
                          nb: result.num_checkins})
            model.append({type: "tips",
                          name: qsTr("Tips"),
                          icon: "qrc:///images/ic_tips.png",
                          nb: result.num_tips})
            model.append({type: "photos",
                          name: qsTr("Album"),
                          icon: "qrc:///images/ic_photos.png",
                          nb: result.num_photos})
            model.append({type: "map",
                          name: qsTr("Map"),
                          icon: "qrc:///images/ic_map.png",
                          nb: undefined})
        }
    }

    onGuidChanged: {
        refresh();
    }

    /// XXX: This is a little bit over complicated.  The problem is that we
    //       have to do two server requests in order to show the list correctly.
    //       We want the 'waiting' message to be seen during both requests.
    //       To simplify the code we could add a method rootWindow.multiRequest
    //       that would take care of running both requests at the same time.
    function refresh() {
        if (guid === undefined)
            return;
        var url = "/locations/show.json";
        var args = {"guid": guid};
        list.loading = true;
        var onSuccess = function(ret, result) {
            list.loading = false
            addr = result.addr;
            longitude = result.lon;
            latitude = result.lat;
            mayor = result.mayor;
            city = result.city;
            hasCoupon = result.hascoupon;

            var additionalCoupons = [];
            if (result.mayor_invitation) {
                additionalCoupons.push({
                    "name": qsTr("Mayor Coupon"),
                    "description": result.mayor_invitation,
                    "is_got": result.mayor && mayor.id === rootWindow.user.userId
                });
            }
            for (var i = 0; i < result.text_coupons.length; i++) {
                additionalCoupons.push({
                    "name": qsTr("Jiepang Coupon"),
                    "description": result.text_coupons[i],
                    "is_got": true
                });
            }
            page.additionalCoupons = additionalCoupons;
            list.refresh();
        };
        var onError = function(code, obj) {
            list.loading = false
        };
        rootWindow.request(url, args, null, undefined, onSuccess, onError);
    }

    tools: ToolBarLayout {
        ToolIcon {
            iconId: "toolbar-back"
            onClicked: {
                pageStack.pop()
            }
        }

        ToolIcon {
            iconSource: "qrc:///images/ic_tab_tips.png"
            onClicked: {
                rootWindow.pushPage(Qt.resolvedUrl("WriteTipPage.qml"),
                                    {"guid": page.guid});
            }
        }

        ToolIcon {
            iconSource: "qrc:///images/ic_tab_plan.png"
            onClicked: {
                rootWindow.pushPage(Qt.resolvedUrl("PlanVisitPage.qml"),
                                    {"guid": page.guid});
            }
        }
    }
}
