import QtQuick 1.0
import Qt.labs.components.native 1.0

import "../Common" as Common

Common.Page {
    property string keywords
    property alias menu: menuComponent
    property variant longitude
    property variant latitude
    property bool error

    id: page

    headerButtons {
        Common.ImageButton {
            id: searchBtn
            imageHeight: header.height
            scale: 1
            fillMode: Image.PreserveAspectFit
            anchors.right: parent.right
            smooth: true
            source: "qrc:///images/img_head_btn_search.png"
            pressedSource: "qrc:///images/img_head_btn_search_pressed.png"
            onClicked: {
                if (searchText.show) {
                    searchText.show = false
                    if (searchText.text !== "") {
                        keywords = searchText.text;
                    }
                    return;
                } else {
                    searchText.show = true
                }
            }
        }
        Common.ImageButton {
            id: refreshBtn
            imageHeight: header.height
            scale: 1
            fillMode: Image.PreserveAspectFit
            anchors.right: searchBtn.left
            smooth: true
            source: "qrc:///images/img_head_btn_refresh.png"
            pressedSource: "qrc:///images/img_head_btn_refresh_pressed.png"
            onClicked: {
                searchText.text = ""
                if (keywords)
                    keywords = "" // Will automaically refresh the page.
                else
                    page.refresh();
            }
        }
    }
    Rectangle {
        id: searchText
        color: "lightgrey"
        property bool show: false
        property alias text: searchTextField.text
        anchors {
            top: parent.top
            left: parent.left
            right: parent.right
        }
        opacity: show ? 1 : 0
        height: show ? searchTextField.height + 10 : 0
        TextField {
            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
                margins: 5
            }
            id: searchTextField
            placeholderText: qsTr("Search by Place or Address")
        }
    }

    Common.List {
        id: list
        anchors {
            left: parent.left
            right: parent.right
            top: searchText.bottom
            bottom: parent.bottom
        }

        requestUrl: "/locations/search.json"
        requestParams: {
            if (!longitude && !latitude && keywords)
                return {"q": keywords, "city": rootWindow.user.city}
            return {"lon": longitude, "lat": latitude,
                    "q": keywords, "city": rootWindow.user.city}
        }
        usePages: true
        countParam: "limit" // It is not "count" for this list!
        initialCount: 20
        moreCount: 10

        errorMessage: {
            if (keywords)  // We don't need a location if we use kewords
                return undefined;
            if (error)
                return qsTr("Cannot find location");
            if (longitude === undefined || latitude === undefined)
                return qsTr("Locating");
        }

        delegate: Common.LocationListItem {
            name: model.meta.name
            addr: model.meta.addr
            isSpecial: model.hascoupon
            icon: model.icon

            // Note: This could be directly moved into LocationListItem
            onClicked: {
                rootWindow.pushPage(Qt.resolvedUrl("LocationPage.qml"),
                                    {"name": model.meta.name,
                                    "addr": model.meta.addr,
                                    "guid": model.guid,
                                    "hasCoupon": model.hascoupon,
                                    "longitude": model.long,
                                    "latitude": model.lat })
            }
        }
    }
    Component {
        id: menuComponent
        Menu {
            MenuLayout {
                MenuItem {
                    text: qsTr("Add venue")
                    onClicked: {
                        var dialogComponent = Qt.createComponent("AddLocationDialog.qml");
                        var dialog = dialogComponent.createObject(page);
                        dialog.city = rootWindow.user.city;
                        dialog.open();
                        dialog.accepted.connect(function() {
                            console.debug("Got to new location page");
                        });
                    }
                }
                MenuItem {
                    text: qsTr("Refresh")
                    onClicked: {
                        page.refresh();
                    }
                }

                MenuItem {
                    text: qsTr("More")
                    onClicked: {
                        rootWindow.pushPage(Qt.resolvedUrl("MorePage.qml"));
                    }
                }
                MenuItem {
                    text: qsTr("Quit")
                    property QueryDialog queryDialog
                    onClicked: {
                        if (!queryDialog)
                            queryDialog = quitDialogComponent.createObject(page);
                        queryDialog.open();
                        queryDialog.accepted.connect(Qt.quit);
                    }
                }
            }
        }
    }
    function parseResult(result, model) {
        var parents = result.result.parents;
        for (var i = 0; i < parents.length; i++) {
            var item = parents[i];
            // Small hack because qml doesn't support list in ListModel.
            if (item.categories && item.categories.length > 0) {
                item.icon = item.categories[0].icon;
            }
            model.append(item);
        }
    }
    function refresh() {
        rootWindow.positionManager.refresh();
    }
}
