import QtQuick 1.0
import Qt.labs.components.native 1.0

import "../Common" as Common

Common.Page {
    id: page

    property string login
    property string password
    property bool saveAccount: true
    function verifyInput() {
        if (loginText.text === "" || passwordText.text === "") {
            return false;
        }
        return true
    }


    Image {
        id: bg
        anchors.fill: parent
        source: "qrc:///images/login_bg.png"
        fillMode: Image.PreserveAspectCrop
        smooth: true
    }

    Column {
        anchors {
            top: parent.top
            topMargin: parent.height / 2
            bottom: parent.bottom
            left: parent.left
            right: parent.right
        }

        spacing: 10
        width: page.width
        TextField {
            id: loginText
            anchors {
                left: parent.left
                leftMargin: 10
                right: parent.right
                rightMargin: 10
            }
            placeholderText: qsTr("Account")
            text: page.login
        }
        TextField {
            id: passwordText
            anchors {
                left: parent.left
                leftMargin: 10
                right: parent.right
                rightMargin: 10
            }
            placeholderText: qsTr("Password")
            width: parent.width - parent.spacing
            text: page.password
            echoMode: TextInput.Password
        }
        CheckBox {
            id: saveAccountCheckBox
            anchors {
                left: parent.left
                right: parent.right
                leftMargin: 10
            }
            text: qsTr("Save Account")
            checked: saveAccount
        }

        Common.Button {
            anchors {
                left: parent.left
                leftMargin: 10
                right: parent.right
                rightMargin: 10
            }
            text: qsTr("Sign In")

            onClicked: {
                if (!verifyInput()) {
                    rootWindow.showDialog(qsTr("Cannot sign-in"), qsTr("Username or Password can't be empty."))
                    return
                }

                var login = loginText.text
                var password = passwordText.text
                var saveAccount = saveAccountCheckBox.checked
                rootWindow.signIn(login, password, saveAccount, function(success) {
                    if (success === true) {
                        rootWindow.popPage()
                    }
                })
            }
        }

        Common.Button {
            anchors {
                left: parent.left
                leftMargin: 10
                right: parent.right
                rightMargin: 10
            }
            text: qsTr("Register")
            onClicked: {
                rootWindow.pushPage(Qt.resolvedUrl("RegisterPage.qml"))
            }
        }
    }

    tools: null
}
