import QtQuick 1.0
import Qt.labs.components.native 1.0

import "../Common" as Common

Page {
    property variant userId: rootWindow.user.userId
    property variant userNick: rootWindow.user.nick

    function refresh() {
        tabGroup.currentTab.refresh()
    }

    function showPlacesTab() {
        tabGroup.currentTab = tabPlacesContent
    }

    function refreshFeeds() {
        tabGroup.refreshFeeds();
    }

    id: page

    TabGroup {
        id: tabGroup
        currentTab: tabFeedContent
        anchors { left: parent.left; right: parent.right; top: parent.top; bottom: page.bottom }

        FriendsFeedsPage {
            id: tabFeedContent
            userId: page.userId
        }

        function refreshFeeds() {
            tabFeedContent.refresh();
        }

        LocationSearchPage {
            id: tabPlacesContent
            longitude: positionManager.longitude
            latitude: positionManager.latitude
            error: positionManager.error
        }

        ExplorePage {
            id: tabExploreContent
            longitude: positionManager.longitude
            latitude: positionManager.latitude
            error: positionManager.error
        }

        UserProfilePage {
            id: tabMeContent
            userId: page.userId
            userNick: (page.userNick !== undefined)? page.userNick : ""
        }
    }

    Component {
        id: quitDialogComponent
        QueryDialog {
            titleText: qsTr("Quit Jiepang")
            message: qsTr("So you want to quit Jiepang now?")
            acceptButtonText: qsTr("Quit")
            rejectButtonText: qsTr("Cancel")
        }
    }

    tools: ToolBarLayout {
        id: pageSpecificTools
        ButtonRow {
            id :tabBar
            Common.TabButton {
                id: feedButton
                icon: "qrc:///images/ic_tab_feed.png"
                tab: tabFeedContent
            }
            Common.TabButton {
                id: placesButton
                tab : tabPlacesContent;
                icon:"qrc:///images/ic_tab_place.png"
            }
            Common.TabButton {
                id: exploreButton
                tab: tabExploreContent;
                icon: "qrc:///images/ic_tab_explore.png"
            }
            Common.TabButton {
                id: meButton
                tab: tabMeContent;
                icon: "qrc:///images/ic_tab_profile.png"
            }
        }

        ToolIcon {
            id: menuButton
            iconId: "icon-m-toolbar-view-menu"
            onClicked:  {
                var menu = tabGroup.currentTab.menu.createObject(root)
                menu.open()
            }
        }
    }
}
