import QtQuick 1.0
import Qt.labs.components.native 1.0
import "../Common" as Common
import QtMobility.location 1.2
import "../Common/Network.js" as Network

Common.Page {
    property variant longitude
    property variant latitude
    property bool needShift:false;
    property Coordinate coordinate: Coordinate {
        longitude: 0
        latitude: 0
    }

    id: page
    anchors.fill: parent

    onLongitudeChanged: {
        if (latitude !== undefined && longitude !== undefined)
            coordinate = createCoordinate(latitude, longitude);
    }

    onLatitudeChanged: {
        if (latitude !== undefined && longitude !== undefined)
            coordinate = createCoordinate(latitude, longitude);
    }
    onNeedShiftChanged: {
        if (needShift) {
            var dialog = rootWindow.showWaitDialog()
            Network.doGet("http://loc.desktop.stg.maps.svc.ovi.com/geocoder/rgc/2.0",
                           {"lat":latitude,
                           "long":longitude,
                           "isShifted": "false",
                           "output": "json"} , function(status, obj) {
                               if(status === 200) {
                                   coordinate.longitude = obj.places[0].location.position.longitude;
                                   coordinate.latitude = obj.places[0].location.position.latitude;
                                   map.center = page.coordinate
                                   mapImage.coordinate = page.coordinate
                                   console.debug(("[MapPage.qml]: shifted lat=%1,long=%2")
                                                 .arg(coordinate.latitude).arg(coordinate.longitude))
                               } else{
                                   console.debug("[MapPage.qml]: shift failed!")
                               }
                               dialog.close()
                           });
        }
        console.debug(("[MapPage.qml]: shifting...lat=%1,long=%2")
                      .arg(latitude).arg(longitude));
    }

    // Little hack to dynamically create a coordinate object.
    function createCoordinate(lat, lon) {
        return Qt.createQmlObject('import QtMobility.location 1.1;' +
                                  'Coordinate {latitude:' + lat +
                                  ';longitude:' + lon + ';}', page);
    }
    Map {
        id: map
        plugin : Plugin {
            name : "nokia"
        }
        anchors.fill: parent
        zoomLevel: 14

        center: page.coordinate

        MapImage {
            id: mapImage
            source: "qrc:///images/img_place.png"
            coordinate: page.coordinate
            offset {
                x: -24
                y: -48
            }
        }

        Row {
            height: childrenRect.height
            x: (page.width - width) / 2
            y: page.height - height - 10
            Common.ImageButton {
                source: "qrc:///images/zoom_out.png"
                pressedSource: "qrc:///images/zoom_out.png"
                onClicked: {
                    map.zoomLevel -= 1;
                }
            }
            Common.ImageButton {
                source: "qrc:///images/zoom_in.png"
                pressedSource: "qrc:///images/zoom_in.png"
                onClicked: {
                    map.zoomLevel += 1;
                }
            }
        }
    }

    tools: ToolBarLayout {
        ToolIcon {
            iconId: "toolbar-back"
            onClicked: {
                pageStack.pop()
            }
        }
    }

    MouseArea {

        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
            bottom: parent.bottom
            bottomMargin: 60
        }

        property bool mouseDown : false
        property int lastX : -1
        property int lastY : -1

        hoverEnabled : true

        onPressed : {
            mouseDown = true
            lastX = mouse.x
            lastY = mouse.y
        }
        onReleased : {
            mouseDown = false
            lastX = -1
            lastY = -1
        }
        onPositionChanged: {
            if (mouseDown) {
                var dx = mouse.x - lastX
                var dy = mouse.y - lastY
                map.pan(-dx, -dy)
                lastX = mouse.x
                lastY = mouse.y
            }
        }
    }
}
