import QtQuick 1.0
import Qt.labs.components.native 1.0
import QtMobility.systeminfo 1.1

import "../Common" as Common
import "../Common/Network.js" as Network
import "../Common/Agreement.js" as Agreement

Page {
    id: page

    property alias userName: userNameText.text
    property alias email: emailText.text
    property alias password: passwordText.text
    property alias passwordConfirm: passwordConfirmText.text
    property alias city: cityPicker.city
    property alias agreeTerm: agreementBox.checked

    property string replyMessage // Used by the dialog.
    property bool success: false

    anchors.fill: parent

    DeviceInfo {
        id: deviceInfo
    }

    ListModel {
        id: provinces
    }

    ListModel {
        id: cities
    }

    Column {
        anchors.fill: parent
        anchors.margins: 10
        spacing: 10

        TextField {
            id: userNameText
            anchors.left: parent.left
            anchors.right: parent.right
            placeholderText: qsTr("Account Name")
        }

        TextField {
            id: emailText
            anchors.left: parent.left
            anchors.right: parent.right
            placeholderText: qsTr("Email")
        }

        TextField {
            id: passwordText
            anchors.left: parent.left
            anchors.right: parent.right
            placeholderText: qsTr("Password")
            echoMode: TextInput.Password
        }

        TextField {
            id: passwordConfirmText
            anchors.left: parent.left
            anchors.right: parent.right
            placeholderText: qsTr("Confirm Password")
            echoMode: TextInput.Password
        }

        Common.CityPicker {
            id: cityPicker
        }

        CheckBox {
            id: agreementBox
            anchors.left: parent.left
            anchors.right: parent.right
            text: qsTr("Agreement of the Terms")

            onCheckedChanged: {
                if (checked) {
                    agreementDialog.open();
                }
            }

            QueryDialog {
                id: agreementDialog
                titleText: qsTr("Service Agreement")
                message: Agreement.getAgreement()
                acceptButtonText: qsTr("I agree")
            }
        }

        Common.Button {
            anchors.left: parent.left
            anchors.right: parent.right
            text: qsTr("Create Account")
            onClicked: {
                var validation = validate()
                if (validation !== true) {
                    page.replyMessage = validation;
                    registerDialog.open();
                    return;
                }

                var waitDialog = rootWindow.showWaitDialog(qsTr("Creating account"));
                var source = deviceInfo.manufacturer + " " + deviceInfo.model;
                var url = "/account/create.json"
                var args = {"email": email, "name": userName,
                    "password": password, "city": page.city, "source": source};

                Network.doPost(url, args, function(ret, obj) {
                    waitDialog.close();
                    if (ret !== 200) {
                        page.replyMessage = (obj !== undefined && obj.error !== undefined)?
                                            obj.error.message : qsTr("Unknown error");
                        registerDialog.open();
                    } else { // Success
                        success = true;
                        page.replyMessage = qsTr("Signed up successfully, please check your email and confirm");
                        registerDialog.open();
                    }
                });
            }

            // XXX: fix that!  This should be a component that we create every
            // time we use the page.  Right now this is a mess.
            QueryDialog {
                id: registerDialog
                message: page.replyMessage
                acceptButtonText: qsTr("Ok")
                // XXX: replace by a proper signal connection.
                onAccepted: {
                    if (success) {
                        pageStack.pop();
                        var loginPage = pageStack.currentPage;
                        loginPage.login = page.userName;
                        loginPage.password = page.password;
                    }
                }
            }
        }
    }

    tools: ToolBarLayout {
        ToolButton {
            iconSource: "toolbar-back"
            onClicked: {
                pageStack.pop()
            }
        }
    }

    function validate() {
        if (userName === "")
            return qsTr("Must enter a username")
        if (userName.length < 4)
            return qsTr("Username is too short");
        if (email === "")
            return qsTr("Email is required");
        var emailReg = /^([a-zA-Z0-9_.-])+@(([a-zA-Z0-9-])+\.)+([a-zA-Z0-9]{2,4})+$/;
        if (!emailReg.exec(email))
            return qsTr("Invalid Email address");
        if (password === "")
            return qsTr("Must set a password");
        if (password !== passwordConfirm)
            return qsTr("Passwords don't match");
        if (!agreeTerm)
            return qsTr("Please read the Terms of Service");
        return true;
    }

}
