import QtQuick 1.0
import Qt.labs.components.native 1.0
import "../Common" as Common

Common.Page {
    id: root
    property variant userId

    Common.List {
        id: list
        anchors.fill: parent

        requestUrl: "/syncs/setting.json"
        requestParams: {}
        usePages: false
        canGetMore: false

        headerText: qsTr("Sync")

        delegate: Common.ListItem {
            id: listItem
            allowClick: true
            content: Item {
                id: item

                anchors {
                    left: parent.left
                    right: parent.right
                }
                height: childrenRect.height

                Common.Image {
                    id: image
                    anchors.left: parent.left
                    source: model.icon
                }

                Text {
                    id: messageText
                    text: qsTr("Sync to %1").arg(model.name)
                    anchors {
                        left: image.right
                        verticalCenter: image.verticalCenter
                        margins: 10
                    }
                    font.pixelSize: rootWindow.style.fontNormalSize
                }

                CheckBox {
                    anchors {
                        right: parent.right
                        margins: 10
                    }
                    checked:  model.is_set

                    onClicked: {
                        if (!checked) {
                            // TODO use page as the parent (why isn't that working?)
                            var dialog = removeConfirmDialogComponent.createObject(root);
                            dialog.name = model.name;
                            dialog.rejected.connect(function() {checked = true});
                            dialog.accepted.connect(function() {removeSync(model.target)});
                            dialog.open();
                        } else {
                            var onSync = function() {root.refresh()};
                            var onCancel = function() {checked = false};
                            addSync(model.target, model.name, model.url, onSync, onCancel);
                        }
                    }
                }
            }
        }

        function parseResult(result, model) {
            for (var i = 0; i < result.length; i++) {
                model.append(result[i]);
            }
        }
    }

    function addSync(target, name, url, onSync, onCancel) {
        // If we don't provide a url then ask the user for login and password
        if (!url) {
            getLogin(name,
                     function(login, password) {
                         var url = "/syncs/save.json";
                         var args = {target: target, s_id: login, s_pass: password};
                         var onDone = function(ret, obj) {onSync()};
                        rootWindow.request(url, args, undefined, undefined,
                            onDone, onDone);
                    },
                    onCancel
            );
            return;
        }

        // Otherwise if we have a url, just open it.
        var webpage = rootWindow.pushPage(Qt.resolvedUrl("WebPage.qml"), {url: url});
        webpage.statusChanged.connect(function() {
            if (webpage.status === PageStatus.Deactivating) { // We came back
                page.refresh();
            }
        });
    }

    function getLogin(name, callback, onCancel) {
        var dialog = passwordDialogComponent.createObject(root);
        dialog.name = name;
        dialog.accepted.connect(function() {
            callback(dialog.login, dialog.password);
        });
        dialog.rejected.connect(function() {onCancel()});
        dialog.open();
    }

    function removeSync(target) {
        var url = "/syncs/remove.json";
        var args = {target: target}
        var onDone = function(ret, obj) {root.refresh()};
        rootWindow.request(url, args, undefined, undefined, onDone, onDone);
    }

    Component {
        id: removeConfirmDialogComponent
        QueryDialog {
            property string name
            titleText: qsTr("Remove sync to %1").arg(name)
            acceptButtonText: qsTr("Remove")
            rejectButtonText: qsTr("Back")
            message: qsTr("You cannot share your activity to %1 if you stop syncing.").arg(name)
        }
    }

    // XXX: We use this kind of dialog so often we should make it a component.
    Component {
        id: passwordDialogComponent
        QueryDialog {
            id: dialog
            property string name
            property alias login: loginText.text
            property alias password: passwordText.text

            titleText: qsTr("Sync to %1").arg(name)
            acceptButtonText: qsTr("Sync")
            rejectButtonText: qsTr("Cancel")
            content: Column {
                spacing: 10
                anchors {
                    top: parent.top
                    left: parent.left
                    right: parent.right
                    margins: 10
                }

                // Small hack to fix the dialog height.
                onHeightChanged: {
                    dialog.height = height + 130
                }

                TextField {
                    id: loginText
                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    placeholderText: qsTr("%1 Account").arg(name)
                }
                TextField {
                    id: passwordText
                    anchors {
                        left: parent.left
                        right: parent.right
                    }
                    placeholderText: qsTr("Password")
                    echoMode: TextInput.Password
                }
            }
        }
    }
}
