import QtQuick 1.0
import Qt.labs.components.native 1.0
import com.nokia.extras 1.0

import "../Common" as Common

Common.Page {
    id: page
    property alias menu: menuComponent
    property variant avatar
    property string userNick
    property variant userId
    property variant isFriend
    property variant iInvited

    property variant userData // Contains the json object received from the server
    property variant lastCheckin

    headerButtons {
        Common.ImageButton {
            id: moreBtn
            visible: userId === rootWindow.user.userId
            imageHeight: header.height
            scale: 1
            fillMode: Image.PreserveAspectFit
            anchors.right: parent.right
            smooth: true
            source: "qrc:///images/img_head_btn_more.png"
            pressedSource: "qrc:///images/img_head_btn_more_pressed.png"
            opacity: (userId === rootWindow.user.userId)? 1 : 0
            onClicked: {
                rootWindow.pushPage(Qt.resolvedUrl("MorePage.qml"));
            }
        }
        Common.ImageButton {
            id: addFriendBtn
            imageHeight: header.height
            scale: 1
            fillMode: Image.PreserveAspectFit
            anchors.right: moreBtn.left
            source: "qrc:///images/img_head_btn_addfriend.png"
            pressedSource: "qrc:///images/img_head_btn_addfriend_pressed.png"
            opacity: (userId !== rootWindow.user.userId && isFriend === false && iInvited === false)? 1 : 0

            onClicked: {
                var dialogComponent = Qt.createComponent("AddFriendDialog.qml");
                var dialog = dialogComponent.createObject(page);
                var onAccept = function() {
                    var url = "/friends/invite.json";
                    var message = dialog.message.replace('&', '%26');
                    var args = {"message": message, "id": userId};
                    var onSuccess = function(ret, obj) {page.refresh()};
                    rootWindow.request(url, args, undefined, undefined, onSuccess);
                }
                dialog.accepted.connect(onAccept);
                dialog.open();
            }
        }
        Text {
            anchors {
                right: addFriendBtn.left
                verticalCenter: header.verticalCenter
                margins: 10
            }
            text: (iInvited)? qsTr("Friend request sent") : ""
            color: "white"
        }
    }

    Rectangle {
        id: userInfoRect
        anchors.top: parent.top;
        anchors.left: parent.left
        anchors.right: parent.right;
        height: childrenRect.height + 20

        color: "#dbdbdb"
        Common.Image {
            id: image
            source: avatar
            defaultSource: "qrc:///images/img_nopic.png"
            imageHeight: 100
            imageWidth: 100
            anchors.left: parent.left
            anchors.top: parent.top
            anchors.leftMargin: 10
            anchors.topMargin: 10
        }

        Text {
            id: userNickText
            text: userNick
            color: "black"
            font.pixelSize: rootWindow.style.fontLargeSize
            anchors.left: image.right
            anchors.top: image.top
            anchors.leftMargin: 10
        }

        Row {
            anchors {
                left: image.right
                right: parent.right
                bottom: image.bottom
                leftMargin: 10
                rightMargin: 10
            }

            Common.BorderImageButton {
                source: "qrc:///images/bg_stats_left.sci"
                pressedSource: "qrc:///images/bg_stats_left_pressed.sci"
                imageHeight: 50 * rootWindow.style.scale
                imageWidth: parent.width * 0.25
                Column {
                    anchors.fill: parent
                    anchors.leftMargin: 5
                    anchors.topMargin: 5
                    anchors.bottomMargin: 5
                    Text {
                        text: qsTr("Mayor")
                        color: "white"
                        font.pixelSize: rootWindow.style.fontSmallSize
                    }
                    Text {
                        font.bold: true
                        text: (userData)? userData.mayor_num : "-"
                        color: "white"
                        font.pixelSize: rootWindow.style.fontNormalSize
                    }
                }
                onClicked: {
                    if (!userData)
                        return
                    rootWindow.pushPage(Qt.resolvedUrl("MayorsPage.qml"),
                                        {"userId": userId,
                                        "userNick": userNick,
                                        "maxCount": userData.mayor_num})
                }
            }
            Common.BorderImageButton {
                source: "qrc:///images/bg_stats_mid.sci"
                pressedSource: "qrc:///images/bg_stats_mid_pressed.sci"
                imageHeight: 50 * rootWindow.style.scale
                imageWidth: parent.width * 0.27
                onClicked: {
                    rootWindow.pushPage(Qt.resolvedUrl("BadgesSummaryPage.qml"),
                                        {"userId": userId})
                }
                Column {
                    anchors.fill: parent
                    anchors.leftMargin: 5
                    anchors.topMargin: 5
                    anchors.bottomMargin: 5
                    Text {
                        text: qsTr("Badge")
                        color: "white"
                        font.pixelSize: rootWindow.style.fontSmallSize
                    }
                    Text {
                        font.bold: true
                        text:  (userData)? userData.badges_num : "-"
                        color: "white"
                        font.pixelSize: rootWindow.style.fontNormalSize
                    }
                }
            }
            Common.BorderImageButton {
                source: "qrc:///images/bg_stats_right.sci"
                pressedSource: "qrc:///images/bg_stats_right_pressed.sci"
                imageHeight: 50 * rootWindow.style.scale
                imageWidth: parent.width * 0.48
                Column {
                    anchors.fill: parent
                    anchors.leftMargin: 5
                    anchors.topMargin: 5
                    anchors.bottomMargin: 5
                    Text {
                        text: qsTr("Score")
                        color: "white"
                        font.pixelSize: rootWindow.style.fontSmallSize
                    }
                    Text {
                        font.bold: true
                        text: (userData)? userData.points : "-"
                        color: "white"
                        font.pixelSize: rootWindow.style.fontNormalSize
                    }
                }
            }
        }
    }

    Common.List {
        id: list
        anchors.top: userInfoRect.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        autoRefresh: false
        maxCount: 5

        delegate: Common.MenuItem {
            id: item
            text: model.name
            nb: model.nb
            icon: model.icon
            date: model.date

            onClicked: {
                if (model.nb === 0) {
                    // TODO: use a popup?
                    rootWindow.showDialog("", model.emptyText);
                    return;
                }
                switch (model.type) {
                case "lastCheckin":
                    rootWindow.pushPage(Qt.resolvedUrl("LocationPage.qml"),
                                        {"name": lastCheckin.location.name,
                                         "guid": lastCheckin.location.guid});
                    break;
                case "history":
                    if (isFriend === true || userId === rootWindow.user.userId)
                        rootWindow.pushPage(Qt.resolvedUrl("HistoryPage.qml"),
                                            {"maxCount": model.nb, "userId": userId, "userNick": userNick})
                    else
                        rootWindow.showDialog("", qsTr("Visible only to friends"));
                    break;
                case "tips":
                    rootWindow.pushPage(Qt.resolvedUrl("UserTipsPage.qml"),
                                        {"maxCount": model.nb, "userId": userId, "userNick": userNick})
                    break
                case "photos":
                    rootWindow.pushPage(Qt.resolvedUrl("UserGalleryPage.qml"),
                                        {"maxCount": model.nb, "userId": userId, "userNick": userNick})
                    break
                case "friends":
                    rootWindow.pushPage(Qt.resolvedUrl("FriendsPage.qml"),
                                        {"maxCount": model.nb, "userId": userId, "userNick": userNick})
                    break

                default:
                    break
                }
            }
        }

        requestUrl: "/users/counts.json"
        requestParams: {"id": userId}

        // Function that is used to fill the model from the server result.
        function parseResult(result, model) {
            lastCheckin = result.last_checkin

            if ((isFriend || userId === rootWindow.user.userId) && lastCheckin)
                model.append({type: "lastCheckin",
                              name: qsTr("at %1").arg(lastCheckin.location.name),
                              icon: "qrc:///images/listitem_icons_lastcheckin.png",
                              nb: undefined,
                              emptyText: undefined,
                              date: result.last_checkin.created_on});
            else if ((isFriend || userId === rootWindow.user.userId) && !lastCheckin)
                model.append({type: "",
                              name: qsTr("No check-ins yet"),
                              nb: undefined,
                              emptyText: undefined,
                              icon: "qrc:///images/listitem_icons_lastcheckin.png"});
            else if (!isFriend)
                model.append({type: "",
                              name: qsTr("Visible only to friends"),
                              nb: undefined,
                              emptyText: undefined,
                              icon: "qrc:///images/listitem_icons_lastcheckin.png"});

            model.append({type: "history",
                          name: qsTr("History"),
                          emptyText: qsTr("No check-ins yet."),
                          icon: "qrc:///images/ic_history.png",
                          nb: result.num_checkins})
            model.append({type: "tips",
                          name: qsTr("Tips"),
                          emptyText: qsTr("Haven't written any tips yet."),
                          icon: "qrc:///images/ic_tips.png",
                          nb: result.num_tips})
            model.append({type: "photos",
                          name: qsTr("Album"),
                          emptyText: qsTr("No photos yet."),
                          icon: "qrc:///images/ic_photos.png",
                          nb: result.num_photos})
            model.append({type: "friends",
                          name: qsTr("Friends"),
                          emptyText: qsTr("No friends yet."),
                          icon: "qrc:///images/ic_friends.png",
                          nb: result.num_friends})
        }
    }
    Component {
        id: menuComponent
        Menu {
            MenuLayout {
                MenuItem {
                    text: qsTr("Add friend")
                    onClicked: {
                        rootWindow.pushPage(Qt.resolvedUrl("AddFriendPage.qml"));
                    }
                }
                MenuItem {
                    text: qsTr("Friend request")
                    onClicked: {
                        rootWindow.pushPage(Qt.resolvedUrl("FriendRequestsPage.qml"),
                                            {"userId": userId});
                    }
                }
                MenuItem {
                    text: qsTr("Refresh")
                    onClicked: {
                        page.refresh();
                    }
                }

                MenuItem {
                    text: qsTr("More")
                    onClicked: {
                        rootWindow.pushPage(Qt.resolvedUrl("MorePage.qml"));
                    }
                }
                MenuItem {
                    text: qsTr("Quit")
                    property QueryDialog queryDialog
                    onClicked: {
                        if (!queryDialog)
                            queryDialog = quitDialogComponent.createObject(page);
                        queryDialog.open();
                        queryDialog.accepted.connect(Qt.quit);
                    }
                }
            }
        }
    }
    onUserIdChanged: {
        refresh();
    }

    function refresh() {
        if (userId === undefined)
            return;
        list.loading = true;
        var url = "/users/show.json";
        var args = {"id": userId, "apiver":3};
        var onSuccess = function(code, obj) {
            list.loading = false
            avatar = obj.avatar;
            isFriend = (obj.is_friend === "true"); // Why does the server return a string and not a boolean?
            iInvited = obj.i_invited;
            userData = obj;
            list.refresh();
        };
        var onError = function(code, obj) {
            list.loading = false
        };
        rootWindow.request(url, args, null, undefined, onSuccess, onError);
        list.refresh();
    }
}
